ActionSource class

A structure describing the source of an action.

Constructors

ActionSource({required String sourceUri, String? sourceId, String? sourceType})
ActionSource.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceId → String?
The ID of the source.
final
sourceType → String?
The type of the source.
final
sourceUri → String
The URI of the source.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited