AddAssociationResponse class

Constructors

AddAssociationResponse({String? destinationArn, String? sourceArn})
AddAssociationResponse.fromJson(Map<String, dynamic> json)
factory

Properties

destinationArn → String?
The Amazon Resource Name (ARN) of the destination.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceArn → String?
The ARN of the source.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited