AlgorithmStatusDetails class

Specifies the validation and image scan statuses of the algorithm.

Constructors

AlgorithmStatusDetails({List<AlgorithmStatusItem>? imageScanStatuses, List<AlgorithmStatusItem>? validationStatuses})
AlgorithmStatusDetails.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageScanStatuses → List<AlgorithmStatusItem>?
The status of the scan of the algorithm's Docker image container.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validationStatuses → List<AlgorithmStatusItem>?
The status of algorithm validation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited