AlgorithmStatusItem class

Represents the overall status of an algorithm.

Constructors

AlgorithmStatusItem({required String name, required DetailedAlgorithmStatus status, String? failureReason})
AlgorithmStatusItem.fromJson(Map<String, dynamic> json)
factory

Properties

failureReason → String?
if the overall status is Failed, the reason for the failure.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the algorithm for which the overall status is being reported.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → DetailedAlgorithmStatus
The current status.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited