AlgorithmSummary class

Provides summary information about an algorithm.

Constructors

AlgorithmSummary({required String algorithmArn, required String algorithmName, required AlgorithmStatus algorithmStatus, required DateTime creationTime, String? algorithmDescription})
AlgorithmSummary.fromJson(Map<String, dynamic> json)
factory

Properties

algorithmArn → String
The Amazon Resource Name (ARN) of the algorithm.
final
algorithmDescription → String?
A brief description of the algorithm.
final
algorithmName → String
The name of the algorithm that is described by the summary.
final
algorithmStatus → AlgorithmStatus
The overall status of the algorithm.
final
creationTime → DateTime
A timestamp that shows when the algorithm was created.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited