AlgorithmValidationProfile class

Defines a training job and a batch transform job that Amazon SageMaker runs to validate your algorithm.

The data provided in the validation profile is made available to your buyers on AWS Marketplace.

Constructors

AlgorithmValidationProfile({required String profileName, required TrainingJobDefinition trainingJobDefinition, TransformJobDefinition? transformJobDefinition})
AlgorithmValidationProfile.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
profileName → String
The name of the profile for the algorithm. The name must have 1 to 63 characters. Valid characters are a-z, A-Z, 0-9, and - (hyphen).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trainingJobDefinition → TrainingJobDefinition
The TrainingJobDefinition object that describes the training job that Amazon SageMaker runs to validate your algorithm.
final
transformJobDefinition → TransformJobDefinition?
The TransformJobDefinition object that describes the transform job that Amazon SageMaker runs to validate your algorithm.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited