AlgorithmValidationSpecification class

Specifies configurations for one or more training jobs that Amazon SageMaker runs to test the algorithm.

Constructors

AlgorithmValidationSpecification({required List<AlgorithmValidationProfile> validationProfiles, required String validationRole})
AlgorithmValidationSpecification.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validationProfiles → List<AlgorithmValidationProfile>
An array of AlgorithmValidationProfile objects, each of which specifies a training job and batch transform job that Amazon SageMaker runs to validate your algorithm.
final
validationRole → String
The IAM roles that Amazon SageMaker uses to run the training jobs.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited