AppImageConfigDetails class

The configuration for running a SageMaker image as a KernelGateway app.

Constructors

AppImageConfigDetails({String? appImageConfigArn, String? appImageConfigName, DateTime? creationTime, KernelGatewayImageConfig? kernelGatewayImageConfig, DateTime? lastModifiedTime})
AppImageConfigDetails.fromJson(Map<String, dynamic> json)
factory

Properties

appImageConfigArn → String?
The Amazon Resource Name (ARN) of the AppImageConfig.
final
appImageConfigName → String?
The name of the AppImageConfig. Must be unique to your account.
final
creationTime → DateTime?
When the AppImageConfig was created.
final
hashCode → int
The hash code for this object.
no setterinherited
kernelGatewayImageConfig → KernelGatewayImageConfig?
The configuration for the file system and kernels in the SageMaker image.
final
lastModifiedTime → DateTime?
When the AppImageConfig was last modified.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited