AppSpecification class

Configuration to run a processing job in a specified container image.

Constructors

AppSpecification({required String imageUri, List<String>? containerArguments, List<String>? containerEntrypoint})
AppSpecification.fromJson(Map<String, dynamic> json)
factory

Properties

containerArguments → List<String>?
The arguments for a container used to run a processing job.
final
containerEntrypoint → List<String>?
The entrypoint for a container used to run a processing job.
final
hashCode → int
The hash code for this object.
no setterinherited
imageUri → String
The container image to be run by the processing job.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited