ArtifactSource class

A structure describing the source of an artifact.

Constructors

ArtifactSource({required String sourceUri, List<ArtifactSourceType>? sourceTypes})
ArtifactSource.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceTypes → List<ArtifactSourceType>?
A list of source types.
final
sourceUri → String
The URI of the source.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited