AthenaDatasetDefinition class

Configuration for Athena Dataset Definition input.

Constructors

AthenaDatasetDefinition({required String catalog, required String database, required AthenaResultFormat outputFormat, required String outputS3Uri, required String queryString, String? kmsKeyId, AthenaResultCompressionType? outputCompression, String? workGroup})
AthenaDatasetDefinition.fromJson(Map<String, dynamic> json)
factory

Properties

catalog → String
final
database → String
final
hashCode → int
The hash code for this object.
no setterinherited
kmsKeyId → String?
The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt data generated from an Athena query execution.
final
outputCompression → AthenaResultCompressionType?
final
outputFormat → AthenaResultFormat
final
outputS3Uri → String
The location in Amazon S3 where Athena query results are stored.
final
queryString → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workGroup → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited