AutoMLCandidateStep class

Information about the steps for a Candidate, and what step it is working on.

Constructors

AutoMLCandidateStep({required String candidateStepArn, required String candidateStepName, required CandidateStepType candidateStepType})
AutoMLCandidateStep.fromJson(Map<String, dynamic> json)
factory

Properties

candidateStepArn → String
The ARN for the Candidate's step.
final
candidateStepName → String
The name for the Candidate's step.
final
candidateStepType → CandidateStepType
Whether the Candidate is at the transform, training, or processing step.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited