AutoMLChannel class

Similar to Channel. A channel is a named input source that training algorithms can consume. Refer to Channel for detailed descriptions.

Constructors

AutoMLChannel({required AutoMLDataSource dataSource, required String targetAttributeName, CompressionType? compressionType})
AutoMLChannel.fromJson(Map<String, dynamic> json)
factory

Properties

compressionType → CompressionType?
You can use Gzip or None. The default value is None.
final
dataSource → AutoMLDataSource
The data source.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetAttributeName → String
The name of the target variable in supervised learning, a.k.a. 'y'.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited