AutoMLContainerDefinition class

A list of container definitions that describe the different containers that make up one AutoML candidate. Refer to ContainerDefinition for more details.

Constructors

AutoMLContainerDefinition({required String image, required String modelDataUrl, Map<String, String>? environment})
AutoMLContainerDefinition.fromJson(Map<String, dynamic> json)
factory

Properties

environment → Map<String, String>?
Environment variables to set in the container. Refer to ContainerDefinition for more details.
final
hashCode → int
The hash code for this object.
no setterinherited
image → String
The ECR path of the container. Refer to ContainerDefinition for more details.
final
modelDataUrl → String
The location of the model artifacts. Refer to ContainerDefinition for more details.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited