AutoMLJobConfig class

A collection of settings used for a job.

Constructors

AutoMLJobConfig({AutoMLJobCompletionCriteria? completionCriteria, AutoMLSecurityConfig? securityConfig})
AutoMLJobConfig.fromJson(Map<String, dynamic> json)
factory

Properties

completionCriteria → AutoMLJobCompletionCriteria?
How long a job is allowed to run, or how many candidates a job is allowed to generate.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityConfig → AutoMLSecurityConfig?
Security configuration for traffic encryption or Amazon VPC settings.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited