AutoMLJobSummary class

Provides a summary about a job.

Constructors

AutoMLJobSummary({required String autoMLJobArn, required String autoMLJobName, required AutoMLJobSecondaryStatus autoMLJobSecondaryStatus, required AutoMLJobStatus autoMLJobStatus, required DateTime creationTime, required DateTime lastModifiedTime, DateTime? endTime, String? failureReason})
AutoMLJobSummary.fromJson(Map<String, dynamic> json)
factory

Properties

autoMLJobArn → String
The ARN of the job.
final
autoMLJobName → String
The name of the object you are requesting.
final
autoMLJobSecondaryStatus → AutoMLJobSecondaryStatus
The job's secondary status.
final
autoMLJobStatus → AutoMLJobStatus
The job's status.
final
creationTime → DateTime
When the job was created.
final
endTime → DateTime?
The end time of an AutoML job.
final
failureReason → String?
The failure reason of a job.
final
hashCode → int
The hash code for this object.
no setterinherited
lastModifiedTime → DateTime
When the job was last modified.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited