BlueGreenUpdatePolicy class

Currently, the BlueGreenUpdatePolicy API is not supported.

Constructors

BlueGreenUpdatePolicy({required TrafficRoutingConfig trafficRoutingConfiguration, int? maximumExecutionTimeoutInSeconds, int? terminationWaitInSeconds})
BlueGreenUpdatePolicy.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
maximumExecutionTimeoutInSeconds → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
terminationWaitInSeconds → int?
final
trafficRoutingConfiguration → TrafficRoutingConfig
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited