CaptureContentTypeHeader class

Constructors

CaptureContentTypeHeader({List<String>? csvContentTypes, List<String>? jsonContentTypes})
CaptureContentTypeHeader.fromJson(Map<String, dynamic> json)
factory

Properties

csvContentTypes → List<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
jsonContentTypes → List<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited