ChannelSpecification class

Defines a named input source, called a channel, to be used by an algorithm.

Constructors

ChannelSpecification({required String name, required List<String> supportedContentTypes, required List<TrainingInputMode> supportedInputModes, String? description, bool? isRequired, List<CompressionType>? supportedCompressionTypes})
ChannelSpecification.fromJson(Map<String, dynamic> json)
factory

Properties

description → String?
A brief description of the channel.
final
hashCode → int
The hash code for this object.
no setterinherited
isRequired → bool?
Indicates whether the channel is required by the algorithm.
final
name → String
The name of the channel.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedCompressionTypes → List<CompressionType>?
The allowed compression types, if data compression is used.
final
supportedContentTypes → List<String>
The supported MIME types for the data.
final
supportedInputModes → List<TrainingInputMode>
The allowed input mode, either FILE or PIPE.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited