CollectionConfiguration class

Configuration information for the Debugger output tensor collections.

Constructors

CollectionConfiguration({String? collectionName, Map<String, String>? collectionParameters})
CollectionConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

collectionName → String?
The name of the tensor collection. The name must be unique relative to other rule configuration names.
final
collectionParameters → Map<String, String>?
Parameter values for the tensor collection. The allowed parameters are "name", "include_regex", "reduction_config", "save_config", "tensor_names", and "save_histogram".
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited