CompilationJobSummary class

A summary of a model compilation job.

Constructors

CompilationJobSummary({required String compilationJobArn, required String compilationJobName, required CompilationJobStatus compilationJobStatus, required DateTime creationTime, DateTime? compilationEndTime, DateTime? compilationStartTime, TargetDevice? compilationTargetDevice, TargetPlatformAccelerator? compilationTargetPlatformAccelerator, TargetPlatformArch? compilationTargetPlatformArch, TargetPlatformOs? compilationTargetPlatformOs, DateTime? lastModifiedTime})
CompilationJobSummary.fromJson(Map<String, dynamic> json)
factory

Properties

compilationEndTime → DateTime?
The time when the model compilation job completed.
final
compilationJobArn → String
The Amazon Resource Name (ARN) of the model compilation job.
final
compilationJobName → String
The name of the model compilation job that you want a summary for.
final
compilationJobStatus → CompilationJobStatus
The status of the model compilation job.
final
compilationStartTime → DateTime?
The time when the model compilation job started.
final
compilationTargetDevice → TargetDevice?
The type of device that the model will run on after the compilation job has completed.
final
compilationTargetPlatformAccelerator → TargetPlatformAccelerator?
The type of accelerator that the model will run on after the compilation job has completed.
final
compilationTargetPlatformArch → TargetPlatformArch?
The type of architecture that the model will run on after the compilation job has completed.
final
compilationTargetPlatformOs → TargetPlatformOs?
The type of OS that the model will run on after the compilation job has completed.
final
creationTime → DateTime
The time when the model compilation job was created.
final
hashCode → int
The hash code for this object.
no setterinherited
lastModifiedTime → DateTime?
The time when the model compilation job was last modified.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited