ContinuousParameterRange class

A list of continuous hyperparameters to tune.

Constructors

ContinuousParameterRange({required String maxValue, required String minValue, required String name, HyperParameterScalingType? scalingType})
ContinuousParameterRange.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxValue → String
The maximum value for the hyperparameter. The tuning job uses floating-point values between MinValue value and this value for tuning.
final
minValue → String
The minimum value for the hyperparameter. The tuning job uses floating-point values between this value and MaxValuefor tuning.
final
name → String
The name of the continuous hyperparameter to tune.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scalingType → HyperParameterScalingType?
The scale that hyperparameter tuning uses to search the hyperparameter range. For information about choosing a hyperparameter scale, see Hyperparameter Scaling. One of the following values:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited