CreateAutoMLJobResponse class

Constructors

CreateAutoMLJobResponse({required String autoMLJobArn})
CreateAutoMLJobResponse.fromJson(Map<String, dynamic> json)
factory

Properties

autoMLJobArn → String
When a job is created, it is assigned a unique ARN.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited