CreateDomainResponse class

Constructors

CreateDomainResponse({String? domainArn, String? url})
CreateDomainResponse.fromJson(Map<String, dynamic> json)
factory

Properties

domainArn → String?
The Amazon Resource Name (ARN) of the created domain.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String?
The URL to the created domain.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited