CustomImage class

A custom SageMaker image. For more information, see Bring your own SageMaker image.

Constructors

CustomImage({required String appImageConfigName, required String imageName, int? imageVersionNumber})
CustomImage.fromJson(Map<String, dynamic> json)
factory

Properties

appImageConfigName → String
The name of the AppImageConfig.
final
hashCode → int
The hash code for this object.
no setterinherited
imageName → String
The name of the CustomImage. Must be unique to your account.
final
imageVersionNumber → int?
The version number of the CustomImage.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited