DataCaptureConfigSummary class

Constructors

DataCaptureConfigSummary({required CaptureStatus captureStatus, required int currentSamplingPercentage, required String destinationS3Uri, required bool enableCapture, required String kmsKeyId})
DataCaptureConfigSummary.fromJson(Map<String, dynamic> json)
factory

Properties

captureStatus → CaptureStatus
final
currentSamplingPercentage → int
final
destinationS3Uri → String
final
enableCapture → bool
final
hashCode → int
The hash code for this object.
no setterinherited
kmsKeyId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited