DataCatalogConfig class

The meta data of the Glue table which serves as data catalog for the OfflineStore.

Constructors

DataCatalogConfig({required String catalog, required String database, required String tableName})
DataCatalogConfig.fromJson(Map<String, dynamic> json)
factory

Properties

catalog → String
The name of the Glue table catalog.
final
database → String
The name of the Glue table database.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableName → String
The name of the Glue table.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited