DataQualityAppSpecification class

Information about the container that a data quality monitoring job runs.

Constructors

DataQualityAppSpecification({required String imageUri, List<String>? containerArguments, List<String>? containerEntrypoint, Map<String, String>? environment, String? postAnalyticsProcessorSourceUri, String? recordPreprocessorSourceUri})
DataQualityAppSpecification.fromJson(Map<String, dynamic> json)
factory

Properties

containerArguments → List<String>?
The arguments to send to the container that the monitoring job runs.
final
containerEntrypoint → List<String>?
The entrypoint for a container used to run a monitoring job.
final
environment → Map<String, String>?
Sets the environment variables in the container that the monitoring job runs.
final
hashCode → int
The hash code for this object.
no setterinherited
imageUri → String
The container image that the data quality monitoring job runs.
final
postAnalyticsProcessorSourceUri → String?
An Amazon S3 URI to a script that is called after analysis has been performed. Applicable only for the built-in (first party) containers.
final
recordPreprocessorSourceUri → String?
An Amazon S3 URI to a script that is called per row prior to running analysis. It can base64 decode the payload and convert it into a flatted json so that the built-in container can use the converted data. Applicable only for the built-in (first party) containers.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited