DebugRuleEvaluationStatus class

Information about the status of the rule evaluation.

Constructors

DebugRuleEvaluationStatus({DateTime? lastModifiedTime, String? ruleConfigurationName, String? ruleEvaluationJobArn, RuleEvaluationStatus? ruleEvaluationStatus, String? statusDetails})
DebugRuleEvaluationStatus.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastModifiedTime → DateTime?
Timestamp when the rule evaluation status was last modified.
final
ruleConfigurationName → String?
The name of the rule configuration.
final
ruleEvaluationJobArn → String?
The Amazon Resource Name (ARN) of the rule evaluation job.
final
ruleEvaluationStatus → RuleEvaluationStatus?
Status of the rule evaluation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusDetails → String?
Details from the rule evaluation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited