DeployedImage class

Gets the Amazon EC2 Container Registry path of the docker image of the model that is hosted in this ProductionVariant.

If you used the registry/repository:tag form to specify the image path of the primary container when you created the model hosted in this ProductionVariant, the path resolves to a path of the form registry/repository@digest. A digest is a hash value that identifies a specific version of an image. For information about Amazon ECR paths, see Pulling an Image in the Amazon ECR User Guide.

Constructors

DeployedImage({DateTime? resolutionTime, String? resolvedImage, String? specifiedImage})
DeployedImage.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
resolutionTime → DateTime?
The date and time when the image path for the model resolved to the ResolvedImage
final
resolvedImage → String?
The specific digest path of the image hosted in this ProductionVariant.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
specifiedImage → String?
The image path you specified when you created the model.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited