DeploymentConfig class

Currently, the DeploymentConfig API is not supported.

Constructors

DeploymentConfig({required BlueGreenUpdatePolicy blueGreenUpdatePolicy, AutoRollbackConfig? autoRollbackConfiguration})
DeploymentConfig.fromJson(Map<String, dynamic> json)
factory

Properties

autoRollbackConfiguration → AutoRollbackConfig?
final
blueGreenUpdatePolicy → BlueGreenUpdatePolicy
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited