DescribeAlgorithmOutput class

Constructors

DescribeAlgorithmOutput({required String algorithmArn, required String algorithmName, required AlgorithmStatus algorithmStatus, required AlgorithmStatusDetails algorithmStatusDetails, required DateTime creationTime, required TrainingSpecification trainingSpecification, String? algorithmDescription, bool? certifyForMarketplace, InferenceSpecification? inferenceSpecification, String? productId, AlgorithmValidationSpecification? validationSpecification})
DescribeAlgorithmOutput.fromJson(Map<String, dynamic> json)
factory

Properties

algorithmArn → String
The Amazon Resource Name (ARN) of the algorithm.
final
algorithmDescription → String?
A brief summary about the algorithm.
final
algorithmName → String
The name of the algorithm being described.
final
algorithmStatus → AlgorithmStatus
The current status of the algorithm.
final
algorithmStatusDetails → AlgorithmStatusDetails
Details about the current status of the algorithm.
final
certifyForMarketplace → bool?
Whether the algorithm is certified to be listed in AWS Marketplace.
final
creationTime → DateTime
A timestamp specifying when the algorithm was created.
final
hashCode → int
The hash code for this object.
no setterinherited
inferenceSpecification → InferenceSpecification?
Details about inference jobs that the algorithm runs.
final
productId → String?
The product identifier of the algorithm.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trainingSpecification → TrainingSpecification
Details about training jobs run by this algorithm.
final
validationSpecification → AlgorithmValidationSpecification?
Details about configurations for one or more training jobs that Amazon SageMaker runs to test the algorithm.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited