DescribeAutoMLJobResponse class

Constructors

DescribeAutoMLJobResponse({required String autoMLJobArn, required String autoMLJobName, required AutoMLJobSecondaryStatus autoMLJobSecondaryStatus, required AutoMLJobStatus autoMLJobStatus, required DateTime creationTime, required List<AutoMLChannel> inputDataConfig, required DateTime lastModifiedTime, required AutoMLOutputDataConfig outputDataConfig, required String roleArn, AutoMLJobArtifacts? autoMLJobArtifacts, AutoMLJobConfig? autoMLJobConfig, AutoMLJobObjective? autoMLJobObjective, AutoMLCandidate? bestCandidate, DateTime? endTime, String? failureReason, bool? generateCandidateDefinitionsOnly, ProblemType? problemType, ResolvedAttributes? resolvedAttributes})
DescribeAutoMLJobResponse.fromJson(Map<String, dynamic> json)
factory

Properties

autoMLJobArn → String
Returns the job's ARN.
final
autoMLJobArtifacts → AutoMLJobArtifacts?
Returns information on the job's artifacts found in AutoMLJobArtifacts.
final
autoMLJobConfig → AutoMLJobConfig?
Returns the job's config.
final
autoMLJobName → String
Returns the name of a job.
final
autoMLJobObjective → AutoMLJobObjective?
Returns the job's objective.
final
autoMLJobSecondaryStatus → AutoMLJobSecondaryStatus
Returns the job's AutoMLJobSecondaryStatus.
final
autoMLJobStatus → AutoMLJobStatus
Returns the job's AutoMLJobStatus.
final
bestCandidate → AutoMLCandidate?
Returns the job's BestCandidate.
final
creationTime → DateTime
Returns the job's creation time.
final
endTime → DateTime?
Returns the job's end time.
final
failureReason → String?
Returns the job's FailureReason.
final
generateCandidateDefinitionsOnly → bool?
Returns the job's output from GenerateCandidateDefinitionsOnly.
final
hashCode → int
The hash code for this object.
no setterinherited
inputDataConfig → List<AutoMLChannel>
Returns the job's input data config.
final
lastModifiedTime → DateTime
Returns the job's last modified time.
final
outputDataConfig → AutoMLOutputDataConfig
Returns the job's output data config.
final
problemType → ProblemType?
Returns the job's problem type.
final
resolvedAttributes → ResolvedAttributes?
This contains ProblemType, AutoMLJobObjective and CompletionCriteria. They're auto-inferred values, if not provided by you. If you do provide them, then they'll be the same as provided.
final
roleArn → String
The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that has read permission to the input data location and write permission to the output data location in Amazon S3.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited