DescribeDeviceResponse class

Constructors

DescribeDeviceResponse({required String deviceFleetName, required String deviceName, required DateTime registrationTime, String? description, String? deviceArn, String? iotThingName, DateTime? latestHeartbeat, int? maxModels, List<EdgeModel>? models, String? nextToken})
DescribeDeviceResponse.fromJson(Map<String, dynamic> json)
factory

Properties

description → String?
A description of the device.
final
deviceArn → String?
The Amazon Resource Name (ARN) of the device.
final
deviceFleetName → String
The name of the fleet the device belongs to.
final
deviceName → String
The unique identifier of the device.
final
hashCode → int
The hash code for this object.
no setterinherited
iotThingName → String?
The AWS Internet of Things (IoT) object thing name associated with the device.
final
latestHeartbeat → DateTime?
The last heartbeat received from the device.
final
maxModels → int?
The maximum number of models.
final
models → List<EdgeModel>?
Models on the device.
final
nextToken → String?
The response from the last list when returning a list large enough to need tokening.
final
registrationTime → DateTime
The timestamp of the last registration or de-reregistration.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited