DescribeDomainResponse class

Constructors

DescribeDomainResponse({AppNetworkAccessType? appNetworkAccessType, AuthMode? authMode, DateTime? creationTime, UserSettings? defaultUserSettings, String? domainArn, String? domainId, String? domainName, String? failureReason, String? homeEfsFileSystemId, String? homeEfsFileSystemKmsKeyId, String? kmsKeyId, DateTime? lastModifiedTime, String? singleSignOnManagedApplicationInstanceId, DomainStatus? status, List<String>? subnetIds, String? url, String? vpcId})
DescribeDomainResponse.fromJson(Map<String, dynamic> json)
factory

Properties

appNetworkAccessType → AppNetworkAccessType?
Specifies the VPC used for non-EFS traffic. The default value is PublicInternetOnly.
final
authMode → AuthMode?
The domain's authentication mode.
final
creationTime → DateTime?
The creation time.
final
defaultUserSettings → UserSettings?
Settings which are applied to all UserProfiles in this domain, if settings are not explicitly specified in a given UserProfile.
final
domainArn → String?
The domain's Amazon Resource Name (ARN).
final
domainId → String?
The domain ID.
final
domainName → String?
The domain name.
final
failureReason → String?
The failure reason.
final
hashCode → int
The hash code for this object.
no setterinherited
homeEfsFileSystemId → String?
The ID of the Amazon Elastic File System (EFS) managed by this Domain.
final
homeEfsFileSystemKmsKeyId → String?
This member is deprecated and replaced with KmsKeyId.
final
kmsKeyId → String?
The AWS KMS customer managed CMK used to encrypt the EFS volume attached to the domain.
final
lastModifiedTime → DateTime?
The last modified time.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
singleSignOnManagedApplicationInstanceId → String?
The SSO managed application instance ID.
final
status → DomainStatus?
The status.
final
subnetIds → List<String>?
The VPC subnets that Studio uses for communication.
final
url → String?
The domain's URL.
final
vpcId → String?
The ID of the Amazon Virtual Private Cloud (VPC) that Studio uses for communication.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited