DescribeEdgePackagingJobResponse class

Constructors

DescribeEdgePackagingJobResponse({required String edgePackagingJobArn, required String edgePackagingJobName, required EdgePackagingJobStatus edgePackagingJobStatus, String? compilationJobName, DateTime? creationTime, String? edgePackagingJobStatusMessage, DateTime? lastModifiedTime, String? modelArtifact, String? modelName, String? modelSignature, String? modelVersion, EdgeOutputConfig? outputConfig, String? resourceKey, String? roleArn})
DescribeEdgePackagingJobResponse.fromJson(Map<String, dynamic> json)
factory

Properties

compilationJobName → String?
The name of the SageMaker Neo compilation job that is used to locate model artifacts that are being packaged.
final
creationTime → DateTime?
The timestamp of when the packaging job was created.
final
edgePackagingJobArn → String
The Amazon Resource Name (ARN) of the edge packaging job.
final
edgePackagingJobName → String
The name of the edge packaging job.
final
edgePackagingJobStatus → EdgePackagingJobStatus
The current status of the packaging job.
final
edgePackagingJobStatusMessage → String?
Returns a message describing the job status and error messages.
final
hashCode → int
The hash code for this object.
no setterinherited
lastModifiedTime → DateTime?
The timestamp of when the job was last updated.
final
modelArtifact → String?
The Amazon Simple Storage (S3) URI where model artifacts ares stored.
final
modelName → String?
The name of the model.
final
modelSignature → String?
The signature document of files in the model artifact.
final
modelVersion → String?
The version of the model.
final
outputConfig → EdgeOutputConfig?
The output configuration for the edge packaging job.
final
resourceKey → String?
The CMK to use when encrypting the EBS volume the job run on.
final
roleArn → String?
The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker to download and upload the model, and to contact Neo.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited