DescribeEndpointConfigOutput class

Constructors

DescribeEndpointConfigOutput({required DateTime creationTime, required String endpointConfigArn, required String endpointConfigName, required List<ProductionVariant> productionVariants, DataCaptureConfig? dataCaptureConfig, String? kmsKeyId})
DescribeEndpointConfigOutput.fromJson(Map<String, dynamic> json)
factory

Properties

creationTime → DateTime
A timestamp that shows when the endpoint configuration was created.
final
dataCaptureConfig → DataCaptureConfig?
final
endpointConfigArn → String
The Amazon Resource Name (ARN) of the endpoint configuration.
final
endpointConfigName → String
Name of the Amazon SageMaker endpoint configuration.
final
hashCode → int
The hash code for this object.
no setterinherited
kmsKeyId → String?
AWS KMS key ID Amazon SageMaker uses to encrypt data when storing it on the ML storage volume attached to the instance.
final
productionVariants → List<ProductionVariant>
An array of ProductionVariant objects, one for each model that you want to host at this endpoint.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited