DescribeEndpointOutput class

Constructors

DescribeEndpointOutput({required DateTime creationTime, required String endpointArn, required String endpointConfigName, required String endpointName, required EndpointStatus endpointStatus, required DateTime lastModifiedTime, DataCaptureConfigSummary? dataCaptureConfig, String? failureReason, DeploymentConfig? lastDeploymentConfig, List<ProductionVariantSummary>? productionVariants})
DescribeEndpointOutput.fromJson(Map<String, dynamic> json)
factory

Properties

creationTime → DateTime
A timestamp that shows when the endpoint was created.
final
dataCaptureConfig → DataCaptureConfigSummary?
final
endpointArn → String
The Amazon Resource Name (ARN) of the endpoint.
final
endpointConfigName → String
The name of the endpoint configuration associated with this endpoint.
final
endpointName → String
Name of the endpoint.
final
endpointStatus → EndpointStatus
The status of the endpoint.
final
failureReason → String?
If the status of the endpoint is Failed, the reason why it failed.
final
hashCode → int
The hash code for this object.
no setterinherited
lastDeploymentConfig → DeploymentConfig?
The most recent deployment configuration for the endpoint.
final
lastModifiedTime → DateTime
A timestamp that shows when the endpoint was last modified.
final
productionVariants → List<ProductionVariantSummary>?
An array of ProductionVariantSummary objects, one for each model hosted behind this endpoint.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited