DescribeFeatureGroupResponse class

Constructors

DescribeFeatureGroupResponse({required DateTime creationTime, required String eventTimeFeatureName, required List<FeatureDefinition> featureDefinitions, required String featureGroupArn, required String featureGroupName, required String nextToken, required String recordIdentifierFeatureName, String? description, String? failureReason, FeatureGroupStatus? featureGroupStatus, OfflineStoreConfig? offlineStoreConfig, OfflineStoreStatus? offlineStoreStatus, OnlineStoreConfig? onlineStoreConfig, String? roleArn})
DescribeFeatureGroupResponse.fromJson(Map<String, dynamic> json)
factory

Properties

creationTime → DateTime
A timestamp indicating when SageMaker created the FeatureGroup.
final
description → String?
A free form description of the feature group.
final
eventTimeFeatureName → String
The name of the feature that stores the EventTime of a Record in a FeatureGroup.
final
failureReason → String?
The reason that the FeatureGroup failed to be replicated in the OfflineStore. This is failure can occur because:
final
featureDefinitions → List<FeatureDefinition>
A list of the Features in the FeatureGroup. Each feature is defined by a FeatureName and FeatureType.
final
featureGroupArn → String
The Amazon Resource Name (ARN) of the FeatureGroup.
final
featureGroupName → String
he name of the FeatureGroup.
final
featureGroupStatus → FeatureGroupStatus?
The status of the feature group.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String
A token to resume pagination of the list of Features (FeatureDefinitions).
final
offlineStoreConfig → OfflineStoreConfig?
The configuration of the OfflineStore, inducing the S3 location of the OfflineStore, AWS Glue or AWS Hive data catalogue configurations, and the security configuration.
final
offlineStoreStatus → OfflineStoreStatus?
The status of the OfflineStore. Notifies you if replicating data into the OfflineStore has failed. Returns either: Active or Blocked
final
onlineStoreConfig → OnlineStoreConfig?
The configuration for the OnlineStore.
final
recordIdentifierFeatureName → String
The name of the Feature used for RecordIdentifier, whose value uniquely identifies a record stored in the feature store.
final
roleArn → String?
The Amazon Resource Name (ARN) of the IAM execution role used to persist data into the OfflineStore if an OfflineStoreConfig is provided.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited