DescribeFlowDefinitionResponse class

Constructors

DescribeFlowDefinitionResponse({required DateTime creationTime, required String flowDefinitionArn, required String flowDefinitionName, required FlowDefinitionStatus flowDefinitionStatus, required HumanLoopConfig humanLoopConfig, required FlowDefinitionOutputConfig outputConfig, required String roleArn, String? failureReason, HumanLoopActivationConfig? humanLoopActivationConfig, HumanLoopRequestSource? humanLoopRequestSource})
DescribeFlowDefinitionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

creationTime → DateTime
The timestamp when the flow definition was created.
final
failureReason → String?
The reason your flow definition failed.
final
flowDefinitionArn → String
The Amazon Resource Name (ARN) of the flow defintion.
final
flowDefinitionName → String
The Amazon Resource Name (ARN) of the flow definition.
final
flowDefinitionStatus → FlowDefinitionStatus
The status of the flow definition. Valid values are listed below.
final
hashCode → int
The hash code for this object.
no setterinherited
humanLoopActivationConfig → HumanLoopActivationConfig?
An object containing information about what triggers a human review workflow.
final
humanLoopConfig → HumanLoopConfig
An object containing information about who works on the task, the workforce task price, and other task details.
final
humanLoopRequestSource → HumanLoopRequestSource?
Container for configuring the source of human task requests. Used to specify if Amazon Rekognition or Amazon Textract is used as an integration source.
final
outputConfig → FlowDefinitionOutputConfig
An object containing information about the output file.
final
roleArn → String
The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) execution role for the flow definition.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited