DescribeHumanTaskUiResponse class

Constructors

DescribeHumanTaskUiResponse({required DateTime creationTime, required String humanTaskUiArn, required String humanTaskUiName, required UiTemplateInfo uiTemplate, HumanTaskUiStatus? humanTaskUiStatus})
DescribeHumanTaskUiResponse.fromJson(Map<String, dynamic> json)
factory

Properties

creationTime → DateTime
The timestamp when the human task user interface was created.
final
hashCode → int
The hash code for this object.
no setterinherited
humanTaskUiArn → String
The Amazon Resource Name (ARN) of the human task user interface (worker task template).
final
humanTaskUiName → String
The name of the human task user interface (worker task template).
final
humanTaskUiStatus → HumanTaskUiStatus?
The status of the human task user interface (worker task template). Valid values are listed below.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uiTemplate → UiTemplateInfo
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited