DescribeImageResponse class

Constructors

DescribeImageResponse({DateTime? creationTime, String? description, String? displayName, String? failureReason, String? imageArn, String? imageName, ImageStatus? imageStatus, DateTime? lastModifiedTime, String? roleArn})
DescribeImageResponse.fromJson(Map<String, dynamic> json)
factory

Properties

creationTime → DateTime?
When the image was created.
final
description → String?
The description of the image.
final
displayName → String?
The name of the image as displayed.
final
failureReason → String?
When a create, update, or delete operation fails, the reason for the failure.
final
hashCode → int
The hash code for this object.
no setterinherited
imageArn → String?
The Amazon Resource Name (ARN) of the image.
final
imageName → String?
The name of the image.
final
imageStatus → ImageStatus?
The status of the image.
final
lastModifiedTime → DateTime?
When the image was last modified.
final
roleArn → String?
The Amazon Resource Name (ARN) of the IAM role that enables Amazon SageMaker to perform tasks on your behalf.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited