DescribeImageVersionResponse class

Constructors

DescribeImageVersionResponse({String? baseImage, String? containerImage, DateTime? creationTime, String? failureReason, String? imageArn, String? imageVersionArn, ImageVersionStatus? imageVersionStatus, DateTime? lastModifiedTime, int? version})
DescribeImageVersionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

baseImage → String?
The registry path of the container image on which this image version is based.
final
containerImage → String?
The registry path of the container image that contains this image version.
final
creationTime → DateTime?
When the version was created.
final
failureReason → String?
When a create or delete operation fails, the reason for the failure.
final
hashCode → int
The hash code for this object.
no setterinherited
imageArn → String?
The Amazon Resource Name (ARN) of the image the version is based on.
final
imageVersionArn → String?
The ARN of the version.
final
imageVersionStatus → ImageVersionStatus?
The status of the version.
final
lastModifiedTime → DateTime?
When the version was last modified.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → int?
The version number.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited