DescribeModelOutput class

Constructors

DescribeModelOutput({required DateTime creationTime, required String executionRoleArn, required String modelArn, required String modelName, List<ContainerDefinition>? containers, bool? enableNetworkIsolation, ContainerDefinition? primaryContainer, VpcConfig? vpcConfig})
DescribeModelOutput.fromJson(Map<String, dynamic> json)
factory

Properties

containers → List<ContainerDefinition>?
The containers in the inference pipeline.
final
creationTime → DateTime
A timestamp that shows when the model was created.
final
enableNetworkIsolation → bool?
If True, no inbound or outbound network calls can be made to or from the model container.
final
executionRoleArn → String
The Amazon Resource Name (ARN) of the IAM role that you specified for the model.
final
hashCode → int
The hash code for this object.
no setterinherited
modelArn → String
The Amazon Resource Name (ARN) of the model.
final
modelName → String
Name of the Amazon SageMaker model.
final
primaryContainer → ContainerDefinition?
The location of the primary inference code, associated artifacts, and custom environment map that the inference code uses when it is deployed in production.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vpcConfig → VpcConfig?
A VpcConfig object that specifies the VPC that this model has access to. For more information, see Protect Endpoints by Using an Amazon Virtual Private Cloud
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited