DescribeModelPackageOutput class

Constructors

DescribeModelPackageOutput({required DateTime creationTime, required String modelPackageArn, required String modelPackageName, required ModelPackageStatus modelPackageStatus, required ModelPackageStatusDetails modelPackageStatusDetails, String? approvalDescription, bool? certifyForMarketplace, UserContext? createdBy, InferenceSpecification? inferenceSpecification, UserContext? lastModifiedBy, DateTime? lastModifiedTime, MetadataProperties? metadataProperties, ModelApprovalStatus? modelApprovalStatus, ModelMetrics? modelMetrics, String? modelPackageDescription, String? modelPackageGroupName, int? modelPackageVersion, SourceAlgorithmSpecification? sourceAlgorithmSpecification, ModelPackageValidationSpecification? validationSpecification})
DescribeModelPackageOutput.fromJson(Map<String, dynamic> json)
factory

Properties

approvalDescription → String?
A description provided for the model approval.
final
certifyForMarketplace → bool?
Whether the model package is certified for listing on AWS Marketplace.
final
createdBy → UserContext?
final
creationTime → DateTime
A timestamp specifying when the model package was created.
final
hashCode → int
The hash code for this object.
no setterinherited
inferenceSpecification → InferenceSpecification?
Details about inference jobs that can be run with models based on this model package.
final
lastModifiedBy → UserContext?
final
lastModifiedTime → DateTime?
The last time the model package was modified.
final
metadataProperties → MetadataProperties?
final
modelApprovalStatus → ModelApprovalStatus?
The approval status of the model package.
final
modelMetrics → ModelMetrics?
Metrics for the model.
final
modelPackageArn → String
The Amazon Resource Name (ARN) of the model package.
final
modelPackageDescription → String?
A brief summary of the model package.
final
modelPackageGroupName → String?
If the model is a versioned model, the name of the model group that the versioned model belongs to.
final
modelPackageName → String
The name of the model package being described.
final
modelPackageStatus → ModelPackageStatus
The current status of the model package.
final
modelPackageStatusDetails → ModelPackageStatusDetails
Details about the current status of the model package.
final
modelPackageVersion → int?
The version of the model package.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceAlgorithmSpecification → SourceAlgorithmSpecification?
Details about the algorithm that was used to create the model package.
final
validationSpecification → ModelPackageValidationSpecification?
Configurations for one or more transform jobs that Amazon SageMaker runs to test the model package.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited