DescribeProcessingJobResponse class

Constructors

DescribeProcessingJobResponse({required AppSpecification appSpecification, required DateTime creationTime, required String processingJobArn, required String processingJobName, required ProcessingJobStatus processingJobStatus, required ProcessingResources processingResources, String? autoMLJobArn, Map<String, String>? environment, String? exitMessage, ExperimentConfig? experimentConfig, String? failureReason, DateTime? lastModifiedTime, String? monitoringScheduleArn, NetworkConfig? networkConfig, DateTime? processingEndTime, List<ProcessingInput>? processingInputs, ProcessingOutputConfig? processingOutputConfig, DateTime? processingStartTime, String? roleArn, ProcessingStoppingCondition? stoppingCondition, String? trainingJobArn})
DescribeProcessingJobResponse.fromJson(Map<String, dynamic> json)
factory

Properties

appSpecification → AppSpecification
Configures the processing job to run a specified container image.
final
autoMLJobArn → String?
The ARN of an AutoML job associated with this processing job.
final
creationTime → DateTime
The time at which the processing job was created.
final
environment → Map<String, String>?
The environment variables set in the Docker container.
final
exitMessage → String?
An optional string, up to one KB in size, that contains metadata from the processing container when the processing job exits.
final
experimentConfig → ExperimentConfig?
The configuration information used to create an experiment.
final
failureReason → String?
A string, up to one KB in size, that contains the reason a processing job failed, if it failed.
final
hashCode → int
The hash code for this object.
no setterinherited
lastModifiedTime → DateTime?
The time at which the processing job was last modified.
final
monitoringScheduleArn → String?
The ARN of a monitoring schedule for an endpoint associated with this processing job.
final
networkConfig → NetworkConfig?
Networking options for a processing job.
final
processingEndTime → DateTime?
The time at which the processing job completed.
final
processingInputs → List<ProcessingInput>?
The inputs for a processing job.
final
processingJobArn → String
The Amazon Resource Name (ARN) of the processing job.
final
processingJobName → String
The name of the processing job. The name must be unique within an AWS Region in the AWS account.
final
processingJobStatus → ProcessingJobStatus
Provides the status of a processing job.
final
processingOutputConfig → ProcessingOutputConfig?
Output configuration for the processing job.
final
processingResources → ProcessingResources
Identifies the resources, ML compute instances, and ML storage volumes to deploy for a processing job. In distributed training, you specify more than one instance.
final
processingStartTime → DateTime?
The time at which the processing job started.
final
roleArn → String?
The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to perform tasks on your behalf.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stoppingCondition → ProcessingStoppingCondition?
The time limit for how long the processing job is allowed to run.
final
trainingJobArn → String?
The ARN of a training job associated with this processing job.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited