DescribeProjectOutput class

Constructors

DescribeProjectOutput({required DateTime creationTime, required String projectArn, required String projectId, required String projectName, required ProjectStatus projectStatus, required ServiceCatalogProvisioningDetails serviceCatalogProvisioningDetails, UserContext? createdBy, String? projectDescription, ServiceCatalogProvisionedProductDetails? serviceCatalogProvisionedProductDetails})
DescribeProjectOutput.fromJson(Map<String, dynamic> json)
factory

Properties

createdBy → UserContext?
final
creationTime → DateTime
The time when the project was created.
final
hashCode → int
The hash code for this object.
no setterinherited
projectArn → String
The Amazon Resource Name (ARN) of the project.
final
projectDescription → String?
The description of the project.
final
projectId → String
The ID of the project.
final
projectName → String
The name of the project.
final
projectStatus → ProjectStatus
The status of the project.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceCatalogProvisionedProductDetails → ServiceCatalogProvisionedProductDetails?
Information about a provisioned service catalog product.
final
serviceCatalogProvisioningDetails → ServiceCatalogProvisioningDetails
Information used to provision a service catalog product. For information, see What is AWS Service Catalog.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited