DescribeTransformJobResponse class

Constructors

DescribeTransformJobResponse({required DateTime creationTime, required String modelName, required TransformInput transformInput, required String transformJobArn, required String transformJobName, required TransformJobStatus transformJobStatus, required TransformResources transformResources, String? autoMLJobArn, BatchStrategy? batchStrategy, DataProcessing? dataProcessing, Map<String, String>? environment, ExperimentConfig? experimentConfig, String? failureReason, String? labelingJobArn, int? maxConcurrentTransforms, int? maxPayloadInMB, ModelClientConfig? modelClientConfig, DateTime? transformEndTime, TransformOutput? transformOutput, DateTime? transformStartTime})
DescribeTransformJobResponse.fromJson(Map<String, dynamic> json)
factory

Properties

autoMLJobArn → String?
The Amazon Resource Name (ARN) of the AutoML transform job.
final
batchStrategy → BatchStrategy?
Specifies the number of records to include in a mini-batch for an HTTP inference request. A record is a single unit of input data that inference can be made on. For example, a single line in a CSV file is a record.
final
creationTime → DateTime
A timestamp that shows when the transform Job was created.
final
dataProcessing → DataProcessing?
final
environment → Map<String, String>?
The environment variables to set in the Docker container. We support up to 16 key and values entries in the map.
final
experimentConfig → ExperimentConfig?
final
failureReason → String?
If the transform job failed, FailureReason describes why it failed. A transform job creates a log file, which includes error messages, and stores it as an Amazon S3 object. For more information, see Log Amazon SageMaker Events with Amazon CloudWatch.
final
hashCode → int
The hash code for this object.
no setterinherited
labelingJobArn → String?
The Amazon Resource Name (ARN) of the Amazon SageMaker Ground Truth labeling job that created the transform or training job.
final
maxConcurrentTransforms → int?
The maximum number of parallel requests on each instance node that can be launched in a transform job. The default value is 1.
final
maxPayloadInMB → int?
The maximum payload size, in MB, used in the transform job.
final
modelClientConfig → ModelClientConfig?
The timeout and maximum number of retries for processing a transform job invocation.
final
modelName → String
The name of the model used in the transform job.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transformEndTime → DateTime?
Indicates when the transform job has been completed, or has stopped or failed. You are billed for the time interval between this time and the value of TransformStartTime.
final
transformInput → TransformInput
Describes the dataset to be transformed and the Amazon S3 location where it is stored.
final
transformJobArn → String
The Amazon Resource Name (ARN) of the transform job.
final
transformJobName → String
The name of the transform job.
final
transformJobStatus → TransformJobStatus
The status of the transform job. If the transform job failed, the reason is returned in the FailureReason field.
final
transformOutput → TransformOutput?
Identifies the Amazon S3 location where you want Amazon SageMaker to save the results from the transform job.
final
transformResources → TransformResources
Describes the resources, including ML instance types and ML instance count, to use for the transform job.
final
transformStartTime → DateTime?
Indicates when the transform job starts on ML instances. You are billed for the time interval between this time and the value of TransformEndTime.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited