DescribeUserProfileResponse class

Constructors

DescribeUserProfileResponse({DateTime? creationTime, String? domainId, String? failureReason, String? homeEfsFileSystemUid, DateTime? lastModifiedTime, String? singleSignOnUserIdentifier, String? singleSignOnUserValue, UserProfileStatus? status, String? userProfileArn, String? userProfileName, UserSettings? userSettings})
DescribeUserProfileResponse.fromJson(Map<String, dynamic> json)
factory

Properties

creationTime → DateTime?
The creation time.
final
domainId → String?
The ID of the domain that contains the profile.
final
failureReason → String?
The failure reason.
final
hashCode → int
The hash code for this object.
no setterinherited
homeEfsFileSystemUid → String?
The ID of the user's profile in the Amazon Elastic File System (EFS) volume.
final
lastModifiedTime → DateTime?
The last modified time.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
singleSignOnUserIdentifier → String?
The SSO user identifier.
final
singleSignOnUserValue → String?
The SSO user value.
final
status → UserProfileStatus?
The status.
final
userProfileArn → String?
The user profile Amazon Resource Name (ARN).
final
userProfileName → String?
The user profile name.
final
userSettings → UserSettings?
A collection of settings.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited