Device class

Information of a particular device.

Constructors

Device({required String deviceName, String? description, String? iotThingName})

Properties

description → String?
Description of the device.
final
deviceName → String
The name of the device.
final
hashCode → int
The hash code for this object.
no setterinherited
iotThingName → String?
AWS Internet of Things (IoT) object name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited