DeviceSummary class

Summary of the device.

Constructors

DeviceSummary({required String deviceArn, required String deviceName, String? description, String? deviceFleetName, String? iotThingName, DateTime? latestHeartbeat, List<EdgeModelSummary>? models, DateTime? registrationTime})
DeviceSummary.fromJson(Map<String, dynamic> json)
factory

Properties

description → String?
A description of the device.
final
deviceArn → String
Amazon Resource Name (ARN) of the device.
final
deviceFleetName → String?
The name of the fleet the device belongs to.
final
deviceName → String
The unique identifier of the device.
final
hashCode → int
The hash code for this object.
no setterinherited
iotThingName → String?
The AWS Internet of Things (IoT) object thing name associated with the device..
final
latestHeartbeat → DateTime?
The last heartbeat received from the device.
final
models → List<EdgeModelSummary>?
Models on the device.
final
registrationTime → DateTime?
The timestamp of the last registration or de-reregistration.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited