DisassociateTrialComponentResponse class

Constructors

DisassociateTrialComponentResponse({String? trialArn, String? trialComponentArn})
DisassociateTrialComponentResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trialArn → String?
The Amazon Resource Name (ARN) of the trial.
final
trialComponentArn → String?
The ARN of the trial component.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited