EdgeModel class

The model on the edge device.

Constructors

EdgeModel({required String modelName, required String modelVersion, DateTime? latestInference, DateTime? latestSampleTime})
EdgeModel.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
latestInference → DateTime?
The timestamp of the last inference that was made.
final
latestSampleTime → DateTime?
The timestamp of the last data sample taken.
final
modelName → String
The name of the model.
final
modelVersion → String
The model version.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited