EdgeModelStat class

Status of edge devices with this model.

Constructors

EdgeModelStat({required int activeDeviceCount, required int connectedDeviceCount, required String modelName, required String modelVersion, required int offlineDeviceCount, required int samplingDeviceCount})
EdgeModelStat.fromJson(Map<String, dynamic> json)
factory

Properties

activeDeviceCount → int
The number of devices that have this model version, a heart beat, and are currently running.
final
connectedDeviceCount → int
The number of devices that have this model version and have a heart beat.
final
hashCode → int
The hash code for this object.
no setterinherited
modelName → String
The name of the model.
final
modelVersion → String
The model version.
final
offlineDeviceCount → int
The number of devices that have this model version and do not have a heart beat.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samplingDeviceCount → int
The number of devices with this model version and are producing sample data.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited