EdgeOutputConfig class

The output configuration.

Constructors

EdgeOutputConfig({required String s3OutputLocation, String? kmsKeyId})
EdgeOutputConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
kmsKeyId → String?
The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt data on the storage volume after compilation job. If you don't provide a KMS key ID, Amazon SageMaker uses the default KMS key for Amazon S3 for your role's account.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3OutputLocation → String
The Amazon Simple Storage (S3) bucker URI.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited