Endpoint class

A hosted endpoint for real-time inference.

Constructors

Endpoint({required DateTime creationTime, required String endpointArn, required String endpointConfigName, required String endpointName, required EndpointStatus endpointStatus, required DateTime lastModifiedTime, DataCaptureConfigSummary? dataCaptureConfig, String? failureReason, List<MonitoringSchedule>? monitoringSchedules, List<ProductionVariantSummary>? productionVariants, List<Tag>? tags})
Endpoint.fromJson(Map<String, dynamic> json)
factory

Properties

creationTime → DateTime
The time that the endpoint was created.
final
dataCaptureConfig → DataCaptureConfigSummary?
final
endpointArn → String
The Amazon Resource Name (ARN) of the endpoint.
final
endpointConfigName → String
The endpoint configuration associated with the endpoint.
final
endpointName → String
The name of the endpoint.
final
endpointStatus → EndpointStatus
The status of the endpoint.
final
failureReason → String?
If the endpoint failed, the reason it failed.
final
hashCode → int
The hash code for this object.
no setterinherited
lastModifiedTime → DateTime
The last time the endpoint was modified.
final
monitoringSchedules → List<MonitoringSchedule>?
A list of monitoring schedules for the endpoint. For information about model monitoring, see Amazon SageMaker Model Monitor.
final
productionVariants → List<ProductionVariantSummary>?
A list of the production variants hosted on the endpoint. Each production variant is a model.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<Tag>?
A list of the tags associated with the endpoint. For more information, see Tagging AWS resources in the AWS General Reference Guide.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited