EndpointInput class

Input object for the endpoint

Constructors

EndpointInput({required String endpointName, required String localPath, String? endTimeOffset, String? featuresAttribute, String? inferenceAttribute, String? probabilityAttribute, double? probabilityThresholdAttribute, ProcessingS3DataDistributionType? s3DataDistributionType, ProcessingS3InputMode? s3InputMode, String? startTimeOffset})
EndpointInput.fromJson(Map<String, dynamic> json)
factory

Properties

endpointName → String
An endpoint in customer's account which has enabled DataCaptureConfig enabled.
final
endTimeOffset → String?
If specified, monitoring jobs substract this time from the end time. For information about using offsets for scheduling monitoring jobs, see Schedule Model Quality Monitoring Jobs.
final
featuresAttribute → String?
The attributes of the input data that are the input features.
final
hashCode → int
The hash code for this object.
no setterinherited
inferenceAttribute → String?
The attribute of the input data that represents the ground truth label.
final
localPath → String
Path to the filesystem where the endpoint data is available to the container.
final
probabilityAttribute → String?
In a classification problem, the attribute that represents the class probability.
final
probabilityThresholdAttribute → double?
The threshold for the class probability to be evaluated as a positive result.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3DataDistributionType → ProcessingS3DataDistributionType?
Whether input data distributed in Amazon S3 is fully replicated or sharded by an S3 key. Defauts to FullyReplicated
final
s3InputMode → ProcessingS3InputMode?
Whether the Pipe or File is used as the input mode for transfering data for the monitoring job. Pipe mode is recommended for large datasets. File mode is useful for small files that fit in memory. Defaults to File.
final
startTimeOffset → String?
If specified, monitoring jobs substract this time from the start time. For information about using offsets for scheduling monitoring jobs, see Schedule Model Quality Monitoring Jobs.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited