Experiment class

The properties of an experiment as returned by the Search API.

Constructors

Experiment({UserContext? createdBy, DateTime? creationTime, String? description, String? displayName, String? experimentArn, String? experimentName, UserContext? lastModifiedBy, DateTime? lastModifiedTime, ExperimentSource? source, List<Tag>? tags})
Experiment.fromJson(Map<String, dynamic> json)
factory

Properties

createdBy → UserContext?
final
creationTime → DateTime?
When the experiment was created.
final
description → String?
The description of the experiment.
final
displayName → String?
The name of the experiment as displayed. If DisplayName isn't specified, ExperimentName is displayed.
final
experimentArn → String?
The Amazon Resource Name (ARN) of the experiment.
final
experimentName → String?
The name of the experiment.
final
hashCode → int
The hash code for this object.
no setterinherited
lastModifiedBy → UserContext?
final
lastModifiedTime → DateTime?
When the experiment was last modified.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → ExperimentSource?
final
tags → List<Tag>?
The list of tags that are associated with the experiment. You can use Search API to search on the tags.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited