ExperimentConfig class

Associates a SageMaker job as a trial component with an experiment and trial. Specified when you call the following APIs:

Constructors

ExperimentConfig({String? experimentName, String? trialComponentDisplayName, String? trialName})
ExperimentConfig.fromJson(Map<String, dynamic> json)
factory

Properties

experimentName → String?
The name of an existing experiment to associate the trial component with.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trialComponentDisplayName → String?
The display name for the trial component. If this key isn't specified, the display name is the trial component name.
final
trialName → String?
The name of an existing trial to associate the trial component with. If not specified, a new trial is created.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited