FeatureDefinition class

A list of features. You must include FeatureName and FeatureType. Valid feature FeatureTypes are Integral, Fractional and String.

Constructors

FeatureDefinition({String? featureName, FeatureType? featureType})
FeatureDefinition.fromJson(Map<String, dynamic> json)
factory

Properties

featureName → String?
The name of a feature. The type must be a string. FeatureName cannot be any of the following: is_deleted, write_time, api_invocation_time.
final
featureType → FeatureType?
The value type of a feature. Valid values are Integral, Fractional, or String.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited