FeatureGroup class

Amazon SageMaker Feature Store stores features in a collection called Feature Group. A Feature Group can be visualized as a table which has rows, with a unique identifier for each row where each column in the table is a feature. In principle, a Feature Group is composed of features and values per features.

Constructors

FeatureGroup({DateTime? creationTime, String? description, String? eventTimeFeatureName, String? failureReason, List<FeatureDefinition>? featureDefinitions, String? featureGroupArn, String? featureGroupName, FeatureGroupStatus? featureGroupStatus, OfflineStoreConfig? offlineStoreConfig, OfflineStoreStatus? offlineStoreStatus, OnlineStoreConfig? onlineStoreConfig, String? recordIdentifierFeatureName, String? roleArn, List<Tag>? tags})
FeatureGroup.fromJson(Map<String, dynamic> json)
factory

Properties

creationTime → DateTime?
The time a FeatureGroup was created.
final
description → String?
A free form description of a FeatureGroup.
final
eventTimeFeatureName → String?
The name of the feature that stores the EventTime of a Record in a FeatureGroup.
final
failureReason → String?
The reason that the FeatureGroup failed to be replicated in the OfflineStore. This is failure may be due to a failure to create a FeatureGroup in or delete a FeatureGroup from the OfflineStore.
final
featureDefinitions → List<FeatureDefinition>?
A list of Features. Each Feature must include a FeatureName and a FeatureType.
final
featureGroupArn → String?
The Amazon Resource Name (ARN) of a FeatureGroup.
final
featureGroupName → String?
The name of the FeatureGroup.
final
featureGroupStatus → FeatureGroupStatus?
A FeatureGroup status.
final
hashCode → int
The hash code for this object.
no setterinherited
offlineStoreConfig → OfflineStoreConfig?
final
offlineStoreStatus → OfflineStoreStatus?
final
onlineStoreConfig → OnlineStoreConfig?
final
recordIdentifierFeatureName → String?
The name of the Feature whose value uniquely identifies a Record defined in the FeatureGroup FeatureDefinitions.
final
roleArn → String?
The Amazon Resource Name (ARN) of the IAM execution role used to create the feature group.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<Tag>?
Tags used to define a FeatureGroup.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited