FeatureGroupSummary class

The name, Arn, CreationTime, FeatureGroup values, LastUpdatedTime and EnableOnlineStorage status of a FeatureGroup.

Constructors

FeatureGroupSummary({required DateTime creationTime, required String featureGroupArn, required String featureGroupName, FeatureGroupStatus? featureGroupStatus, OfflineStoreStatus? offlineStoreStatus})
FeatureGroupSummary.fromJson(Map<String, dynamic> json)
factory

Properties

creationTime → DateTime
A timestamp indicating the time of creation time of the FeatureGroup.
final
featureGroupArn → String
Unique identifier for the FeatureGroup.
final
featureGroupName → String
The name of FeatureGroup.
final
featureGroupStatus → FeatureGroupStatus?
The status of a FeatureGroup. The status can be any of the following: Creating, Created, CreateFail, Deleting or DetailFail.
final
hashCode → int
The hash code for this object.
no setterinherited
offlineStoreStatus → OfflineStoreStatus?
Notifies you if replicating data into the OfflineStore has failed. Returns either: Active or Blocked.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited