FileSystemConfig class

The Amazon Elastic File System (EFS) storage configuration for a SageMaker image.

Constructors

FileSystemConfig({int? defaultGid, int? defaultUid, String? mountPath})
FileSystemConfig.fromJson(Map<String, dynamic> json)
factory

Properties

defaultGid → int?
The default POSIX group ID (GID). If not specified, defaults to 100.
final
defaultUid → int?
The default POSIX user ID (UID). If not specified, defaults to 1000.
final
hashCode → int
The hash code for this object.
no setterinherited
mountPath → String?
The path within the image to mount the user's EFS home directory. The directory should be empty. If not specified, defaults to /home/sagemaker-user.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited