FileSystemDataSource class

Specifies a file system data source for a channel.

Constructors

FileSystemDataSource({required String directoryPath, required FileSystemAccessMode fileSystemAccessMode, required String fileSystemId, required FileSystemType fileSystemType})
FileSystemDataSource.fromJson(Map<String, dynamic> json)
factory

Properties

directoryPath → String
The full path to the directory to associate with the channel.
final
fileSystemAccessMode → FileSystemAccessMode
The access mode of the mount of the directory associated with the channel. A directory can be mounted either in ro (read-only) or rw (read-write) mode.
final
fileSystemId → String
The file system id.
final
fileSystemType → FileSystemType
The file system type.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited