FinalHyperParameterTuningJobObjectiveMetric class

Shows the final value for the objective metric for a training job that was launched by a hyperparameter tuning job. You define the objective metric in the HyperParameterTuningJobObjective parameter of HyperParameterTuningJobConfig.

Properties

hashCode → int
The hash code for this object.
no setterinherited
metricName → String
The name of the objective metric.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → HyperParameterTuningJobObjectiveType?
Whether to minimize or maximize the objective metric. Valid values are Minimize and Maximize.
final
value → double
The value of the objective metric.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited