FlowDefinitionOutputConfig class

Contains information about where human output will be stored.

Constructors

FlowDefinitionOutputConfig({required String s3OutputPath, String? kmsKeyId})
FlowDefinitionOutputConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
kmsKeyId → String?
The Amazon Key Management Service (KMS) key ID for server-side encryption.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3OutputPath → String
The Amazon S3 path where the object containing human output will be made available.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited