FlowDefinitionSummary class

Contains summary information about the flow definition.

Constructors

FlowDefinitionSummary({required DateTime creationTime, required String flowDefinitionArn, required String flowDefinitionName, required FlowDefinitionStatus flowDefinitionStatus, String? failureReason})
FlowDefinitionSummary.fromJson(Map<String, dynamic> json)
factory

Properties

creationTime → DateTime
The timestamp when SageMaker created the flow definition.
final
failureReason → String?
The reason why the flow definition creation failed. A failure reason is returned only when the flow definition status is Failed.
final
flowDefinitionArn → String
The Amazon Resource Name (ARN) of the flow definition.
final
flowDefinitionName → String
The name of the flow definition.
final
flowDefinitionStatus → FlowDefinitionStatus
The status of the flow definition. Valid values:
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited