GitConfig class

Specifies configuration details for a Git repository in your AWS account.

Constructors

GitConfig({required String repositoryUrl, String? branch, String? secretArn})
GitConfig.fromJson(Map<String, dynamic> json)
factory

Properties

branch → String?
The default branch for the Git repository.
final
hashCode → int
The hash code for this object.
no setterinherited
repositoryUrl → String
The URL where the Git repository is located.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretArn → String?
The Amazon Resource Name (ARN) of the AWS Secrets Manager secret that contains the credentials used to access the git repository. The secret must have a staging label of AWSCURRENT and must be in the following format:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited