HumanLoopActivationConfig class

Provides information about how and under what conditions SageMaker creates a human loop. If HumanLoopActivationConfig is not given, then all requests go to humans.

Constructors

HumanLoopActivationConfig({required HumanLoopActivationConditionsConfig humanLoopActivationConditionsConfig})
HumanLoopActivationConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
humanLoopActivationConditionsConfig → HumanLoopActivationConditionsConfig
Container structure for defining under what conditions SageMaker creates a human loop.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited