HumanLoopConfig class

Describes the work to be performed by human workers.

Constructors

HumanLoopConfig({required String humanTaskUiArn, required int taskCount, required String taskDescription, required String taskTitle, required String workteamArn, PublicWorkforceTaskPrice? publicWorkforceTaskPrice, int? taskAvailabilityLifetimeInSeconds, List<String>? taskKeywords, int? taskTimeLimitInSeconds})
HumanLoopConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
humanTaskUiArn → String
The Amazon Resource Name (ARN) of the human task user interface.
final
publicWorkforceTaskPrice → PublicWorkforceTaskPrice?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskAvailabilityLifetimeInSeconds → int?
The length of time that a task remains available for review by human workers.
final
taskCount → int
The number of distinct workers who will perform the same task on each object. For example, if TaskCount is set to 3 for an image classification labeling job, three workers will classify each input image. Increasing TaskCount can improve label accuracy.
final
taskDescription → String
A description for the human worker task.
final
taskKeywords → List<String>?
Keywords used to describe the task so that workers can discover the task.
final
taskTimeLimitInSeconds → int?
The amount of time that a worker has to complete a task. The default value is 3,600 seconds (1 hour)
final
taskTitle → String
A title for the human worker task.
final
workteamArn → String
Amazon Resource Name (ARN) of a team of workers.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited