HyperParameterSpecification class

Defines a hyperparameter to be used by an algorithm.

Constructors

HyperParameterSpecification({required String name, required ParameterType type, String? defaultValue, String? description, bool? isRequired, bool? isTunable, ParameterRange? range})
HyperParameterSpecification.fromJson(Map<String, dynamic> json)
factory

Properties

defaultValue → String?
The default value for this hyperparameter. If a default value is specified, a hyperparameter cannot be required.
final
description → String?
A brief description of the hyperparameter.
final
hashCode → int
The hash code for this object.
no setterinherited
isRequired → bool?
Indicates whether this hyperparameter is required.
final
isTunable → bool?
Indicates whether this hyperparameter is tunable in a hyperparameter tuning job.
final
name → String
The name of this hyperparameter. The name must be unique.
final
range → ParameterRange?
The allowed range for this hyperparameter.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ParameterType
The type of this hyperparameter. The valid types are Integer, Continuous, Categorical, and FreeText.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited