HyperParameterTuningJobSummary class

Provides summary information about a hyperparameter tuning job.

Constructors

HyperParameterTuningJobSummary({required DateTime creationTime, required String hyperParameterTuningJobArn, required String hyperParameterTuningJobName, required HyperParameterTuningJobStatus hyperParameterTuningJobStatus, required ObjectiveStatusCounters objectiveStatusCounters, required HyperParameterTuningJobStrategyType strategy, required TrainingJobStatusCounters trainingJobStatusCounters, DateTime? hyperParameterTuningEndTime, DateTime? lastModifiedTime, ResourceLimits? resourceLimits})
HyperParameterTuningJobSummary.fromJson(Map<String, dynamic> json)
factory

Properties

creationTime → DateTime
The date and time that the tuning job was created.
final
hashCode → int
The hash code for this object.
no setterinherited
hyperParameterTuningEndTime → DateTime?
The date and time that the tuning job ended.
final
hyperParameterTuningJobArn → String
The Amazon Resource Name (ARN) of the tuning job.
final
hyperParameterTuningJobName → String
The name of the tuning job.
final
hyperParameterTuningJobStatus → HyperParameterTuningJobStatus
The status of the tuning job.
final
lastModifiedTime → DateTime?
The date and time that the tuning job was modified.
final
objectiveStatusCounters → ObjectiveStatusCounters
The ObjectiveStatusCounters object that specifies the numbers of training jobs, categorized by objective metric status, that this tuning job launched.
final
resourceLimits → ResourceLimits?
The ResourceLimits object that specifies the maximum number of training jobs and parallel training jobs allowed for this tuning job.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strategy → HyperParameterTuningJobStrategyType
Specifies the search strategy hyperparameter tuning uses to choose which hyperparameters to use for each iteration. Currently, the only valid value is Bayesian.
final
trainingJobStatusCounters → TrainingJobStatusCounters
The TrainingJobStatusCounters object that specifies the numbers of training jobs, categorized by status, that this tuning job launched.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited