Image class

A SageMaker image. A SageMaker image represents a set of container images that are derived from a common base container image. Each of these container images is represented by a SageMaker ImageVersion.

Constructors

Image({required DateTime creationTime, required String imageArn, required String imageName, required ImageStatus imageStatus, required DateTime lastModifiedTime, String? description, String? displayName, String? failureReason})
Image.fromJson(Map<String, dynamic> json)
factory

Properties

creationTime → DateTime
When the image was created.
final
description → String?
The description of the image.
final
displayName → String?
The name of the image as displayed.
final
failureReason → String?
When a create, update, or delete operation fails, the reason for the failure.
final
hashCode → int
The hash code for this object.
no setterinherited
imageArn → String
The Amazon Resource Name (ARN) of the image.
final
imageName → String
The name of the image.
final
imageStatus → ImageStatus
The status of the image.
final
lastModifiedTime → DateTime
When the image was last modified.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited