ImageVersion class

A version of a SageMaker Image. A version represents an existing container image.

Constructors

ImageVersion({required DateTime creationTime, required String imageArn, required String imageVersionArn, required ImageVersionStatus imageVersionStatus, required DateTime lastModifiedTime, required int version, String? failureReason})
ImageVersion.fromJson(Map<String, dynamic> json)
factory

Properties

creationTime → DateTime
When the version was created.
final
failureReason → String?
When a create or delete operation fails, the reason for the failure.
final
hashCode → int
The hash code for this object.
no setterinherited
imageArn → String
The Amazon Resource Name (ARN) of the image the version is based on.
final
imageVersionArn → String
The ARN of the version.
final
imageVersionStatus → ImageVersionStatus
The status of the version.
final
lastModifiedTime → DateTime
When the version was last modified.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → int
The version number.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited