IntegerParameterRange class

For a hyperparameter of the integer type, specifies the range that a hyperparameter tuning job searches.

Constructors

IntegerParameterRange({required String maxValue, required String minValue, required String name, HyperParameterScalingType? scalingType})
IntegerParameterRange.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxValue → String
The maximum value of the hyperparameter to search.
final
minValue → String
The minimum value of the hyperparameter to search.
final
name → String
The name of the hyperparameter to search.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scalingType → HyperParameterScalingType?
The scale that hyperparameter tuning uses to search the hyperparameter range. For information about choosing a hyperparameter scale, see Hyperparameter Scaling. One of the following values:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited