KernelGatewayImageConfig class

The configuration for the file system and kernels in a SageMaker image running as a KernelGateway app.

Constructors

KernelGatewayImageConfig({required List<KernelSpec> kernelSpecs, FileSystemConfig? fileSystemConfig})
KernelGatewayImageConfig.fromJson(Map<String, dynamic> json)
factory

Properties

fileSystemConfig → FileSystemConfig?
The Amazon Elastic File System (EFS) storage configuration for a SageMaker image.
final
hashCode → int
The hash code for this object.
no setterinherited
kernelSpecs → List<KernelSpec>
The specification of the Jupyter kernels in the image.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited