KernelSpec class

The specification of a Jupyter kernel.

Constructors

KernelSpec({required String name, String? displayName})
KernelSpec.fromJson(Map<String, dynamic> json)
factory

Properties

displayName → String?
The display name of the kernel.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the kernel.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited