LabelCounters class

Provides a breakdown of the number of objects labeled.

Constructors

LabelCounters({int? failedNonRetryableError, int? humanLabeled, int? machineLabeled, int? totalLabeled, int? unlabeled})
LabelCounters.fromJson(Map<String, dynamic> json)
factory

Properties

failedNonRetryableError → int?
The total number of objects that could not be labeled due to an error.
final
hashCode → int
The hash code for this object.
no setterinherited
humanLabeled → int?
The total number of objects labeled by a human worker.
final
machineLabeled → int?
The total number of objects labeled by automated data labeling.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalLabeled → int?
The total number of objects labeled.
final
unlabeled → int?
The total number of objects not yet labeled.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited