LabelingJobAlgorithmsConfig class

Provides configuration information for auto-labeling of your data objects. A LabelingJobAlgorithmsConfig object must be supplied in order to use auto-labeling.

Constructors

LabelingJobAlgorithmsConfig({required String labelingJobAlgorithmSpecificationArn, String? initialActiveLearningModelArn, LabelingJobResourceConfig? labelingJobResourceConfig})
LabelingJobAlgorithmsConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
initialActiveLearningModelArn → String?
At the end of an auto-label job Ground Truth sends the Amazon Resource Name (ARN) of the final model used for auto-labeling. You can use this model as the starting point for subsequent similar jobs by providing the ARN of the model here.
final
labelingJobAlgorithmSpecificationArn → String
Specifies the Amazon Resource Name (ARN) of the algorithm used for auto-labeling. You must select one of the following ARNs:
final
labelingJobResourceConfig → LabelingJobResourceConfig?
Provides configuration information for a labeling job.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited