LabelingJobDataSource class

Provides information about the location of input data.

You must specify at least one of the following: S3DataSource or SnsDataSource.

Use SnsDataSource to specify an SNS input topic for a streaming labeling job. If you do not specify and SNS input topic ARN, Ground Truth will create a one-time labeling job.

Use S3DataSource to specify an input manifest file for both streaming and one-time labeling jobs. Adding an S3DataSource is optional if you use SnsDataSource to create a streaming labeling job.

Constructors

LabelingJobDataSource({LabelingJobS3DataSource? s3DataSource, LabelingJobSnsDataSource? snsDataSource})
LabelingJobDataSource.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3DataSource → LabelingJobS3DataSource?
The Amazon S3 location of the input data objects.
final
snsDataSource → LabelingJobSnsDataSource?
An Amazon SNS data source used for streaming labeling jobs.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited