LabelingJobForWorkteamSummary class

Provides summary information for a work team.

Constructors

LabelingJobForWorkteamSummary({required DateTime creationTime, required String jobReferenceCode, required String workRequesterAccountId, LabelCountersForWorkteam? labelCounters, String? labelingJobName, int? numberOfHumanWorkersPerDataObject})
LabelingJobForWorkteamSummary.fromJson(Map<String, dynamic> json)
factory

Properties

creationTime → DateTime
The date and time that the labeling job was created.
final
hashCode → int
The hash code for this object.
no setterinherited
jobReferenceCode → String
A unique identifier for a labeling job. You can use this to refer to a specific labeling job.
final
labelCounters → LabelCountersForWorkteam?
Provides information about the progress of a labeling job.
final
labelingJobName → String?
The name of the labeling job that the work team is assigned to.
final
numberOfHumanWorkersPerDataObject → int?
The configured number of workers per data object.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workRequesterAccountId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited