LabelingJobInputConfig class

Input configuration information for a labeling job.

Constructors

LabelingJobInputConfig({required LabelingJobDataSource dataSource, LabelingJobDataAttributes? dataAttributes})
LabelingJobInputConfig.fromJson(Map<String, dynamic> json)
factory

Properties

dataAttributes → LabelingJobDataAttributes?
Attributes of the data specified by the customer.
final
dataSource → LabelingJobDataSource
The location of the input data.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited