LabelingJobOutput class

Specifies the location of the output produced by the labeling job.

Constructors

LabelingJobOutput({required String outputDatasetS3Uri, String? finalActiveLearningModelArn})
LabelingJobOutput.fromJson(Map<String, dynamic> json)
factory

Properties

finalActiveLearningModelArn → String?
The Amazon Resource Name (ARN) for the most recent Amazon SageMaker model trained as part of automated data labeling.
final
hashCode → int
The hash code for this object.
no setterinherited
outputDatasetS3Uri → String
The Amazon S3 bucket location of the manifest file for labeled data.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited