LabelingJobOutputConfig class

Output configuration information for a labeling job.

Constructors

LabelingJobOutputConfig({required String s3OutputPath, String? kmsKeyId, String? snsTopicArn})
LabelingJobOutputConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
kmsKeyId → String?
The AWS Key Management Service ID of the key used to encrypt the output data, if any.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3OutputPath → String
The Amazon S3 location to write output data.
final
snsTopicArn → String?
An Amazon Simple Notification Service (Amazon SNS) output topic ARN.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited