LabelingJobS3DataSource class

The Amazon S3 location of the input data objects.

Constructors

LabelingJobS3DataSource({required String manifestS3Uri})
LabelingJobS3DataSource.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
manifestS3Uri → String
The Amazon S3 location of the manifest file that describes the input data objects.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited