ListAlgorithmsOutput class

Constructors

ListAlgorithmsOutput({required List<AlgorithmSummary> algorithmSummaryList, String? nextToken})
ListAlgorithmsOutput.fromJson(Map<String, dynamic> json)
factory

Properties

algorithmSummaryList → List<AlgorithmSummary>
>An array of AlgorithmSummary objects, each of which lists an algorithm.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
If the response is truncated, Amazon SageMaker returns this token. To retrieve the next set of algorithms, use it in the subsequent request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited