ListAppImageConfigsResponse class

Constructors

ListAppImageConfigsResponse({List<AppImageConfigDetails>? appImageConfigs, String? nextToken})
ListAppImageConfigsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

appImageConfigs → List<AppImageConfigDetails>?
A list of AppImageConfigs and their properties.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
A token for getting the next set of AppImageConfigs, if there are any.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited