ListCompilationJobsResponse class

Constructors

ListCompilationJobsResponse({required List<CompilationJobSummary> compilationJobSummaries, String? nextToken})
ListCompilationJobsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

compilationJobSummaries → List<CompilationJobSummary>
An array of CompilationJobSummary objects, each describing a model compilation job.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
If the response is truncated, Amazon SageMaker returns this NextToken. To retrieve the next set of model compilation jobs, use this token in the next request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited