ListFeatureGroupsResponse class

Constructors

ListFeatureGroupsResponse({required List<FeatureGroupSummary> featureGroupSummaries, required String nextToken})
ListFeatureGroupsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

featureGroupSummaries → List<FeatureGroupSummary>
A summary of feature groups.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String
A token to resume pagination of ListFeatureGroups results.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited