ListModelExplainabilityJobDefinitionsResponse class

Properties

hashCode → int
The hash code for this object.
no setterinherited
jobDefinitionSummaries → List<MonitoringJobDefinitionSummary>
A JSON array in which each element is a summary for a explainability bias jobs.
final
nextToken → String?
If the response is truncated, Amazon SageMaker returns this token. To retrieve the next set of jobs, use it in the subsequent request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited