ListModelPackageGroupsOutput class

Constructors

ListModelPackageGroupsOutput({required List<ModelPackageGroupSummary> modelPackageGroupSummaryList, String? nextToken})
ListModelPackageGroupsOutput.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
modelPackageGroupSummaryList → List<ModelPackageGroupSummary>
A list of summaries of the model groups in your AWS account.
final
nextToken → String?
If the response is truncated, SageMaker returns this token. To retrieve the next set of model groups, use it in the subsequent request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited