ListModelQualityJobDefinitionsResponse class

Constructors

ListModelQualityJobDefinitionsResponse({required List<MonitoringJobDefinitionSummary> jobDefinitionSummaries, String? nextToken})
ListModelQualityJobDefinitionsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
jobDefinitionSummaries → List<MonitoringJobDefinitionSummary>
A list of summaries of model quality monitoring job definitions.
final
nextToken → String?
If the response is truncated, Amazon SageMaker returns this token. To retrieve the next set of model quality monitoring job definitions, use it in the next request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited