ListNotebookInstanceLifecycleConfigsOutput class

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
If the response is truncated, Amazon SageMaker returns this token. To get the next set of lifecycle configurations, use it in the next request.
final
notebookInstanceLifecycleConfigs → List<NotebookInstanceLifecycleConfigSummary>?
An array of NotebookInstanceLifecycleConfiguration objects, each listing a lifecycle configuration.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited