ListTrainingJobsForHyperParameterTuningJobResponse class

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
If the result of this ListTrainingJobsForHyperParameterTuningJob request was truncated, the response includes a NextToken. To retrieve the next set of training jobs, use the token in the next request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trainingJobSummaries → List<HyperParameterTrainingJobSummary>
A list of TrainingJobSummary objects that describe the training jobs that the ListTrainingJobsForHyperParameterTuningJob request returned.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited