ListTransformJobsResponse class

Constructors

ListTransformJobsResponse({required List<TransformJobSummary> transformJobSummaries, String? nextToken})
ListTransformJobsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
If the response is truncated, Amazon SageMaker returns this token. To retrieve the next set of transform jobs, use it in the next request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transformJobSummaries → List<TransformJobSummary>
An array of TransformJobSummary objects.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited