ListUserProfilesResponse class

Constructors

ListUserProfilesResponse({String? nextToken, List<UserProfileDetails>? userProfiles})
ListUserProfilesResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
If the previous response was truncated, you will receive this token. Use it in your next request to receive the next set of results.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userProfiles → List<UserProfileDetails>?
The list of user profiles.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited