MetadataProperties class

Metadata properties of the tracking entity, trial, or trial component.

Constructors

MetadataProperties({String? commitId, String? generatedBy, String? projectId, String? repository})
MetadataProperties.fromJson(Map<String, dynamic> json)
factory

Properties

commitId → String?
The commit ID.
final
generatedBy → String?
The entity this entity was generated by.
final
hashCode → int
The hash code for this object.
no setterinherited
projectId → String?
The project ID.
final
repository → String?
The repository.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited