MetricData class

The name, value, and date and time of a metric that was emitted to Amazon CloudWatch.

Constructors

MetricData({String? metricName, DateTime? timestamp, double? value})
MetricData.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
metricName → String?
The name of the metric.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime?
The date and time that the algorithm emitted the metric.
final
value → double?
The value of the metric.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited