MetricsSource class

Constructors

MetricsSource({required String contentType, required String s3Uri, String? contentDigest})
MetricsSource.fromJson(Map<String, dynamic> json)
factory

Properties

contentDigest → String?
final
contentType → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3Uri → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited