ModelBiasJobInput class

Inputs for the model bias job.

Constructors

ModelBiasJobInput({required EndpointInput endpointInput, required MonitoringGroundTruthS3Input groundTruthS3Input})
ModelBiasJobInput.fromJson(Map<String, dynamic> json)
factory

Properties

endpointInput → EndpointInput
final
groundTruthS3Input → MonitoringGroundTruthS3Input
Location of ground truth labels to use in model bias job.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited