ModelClientConfig class

Configures the timeout and maximum number of retries for processing a transform job invocation.

Constructors

ModelClientConfig({int? invocationsMaxRetries, int? invocationsTimeoutInSeconds})
ModelClientConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
invocationsMaxRetries → int?
The maximum number of retries when invocation requests are failing.
final
invocationsTimeoutInSeconds → int?
The timeout value in seconds for an invocation request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited