ModelExplainabilityAppSpecification class

Docker container image configuration object for the model explainability job.

Constructors

ModelExplainabilityAppSpecification({required String configUri, required String imageUri, Map<String, String>? environment})
ModelExplainabilityAppSpecification.fromJson(Map<String, dynamic> json)
factory

Properties

configUri → String
JSON formatted S3 file that defines explainability parameters. For more information on this JSON configuration file, see Configure model explainability parameters.
final
environment → Map<String, String>?
Sets the environment variables in the Docker container.
final
hashCode → int
The hash code for this object.
no setterinherited
imageUri → String
The container image to be run by the model explainability job.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited