ModelExplainabilityBaselineConfig class

The configuration for a baseline model explainability job.

Constructors

ModelExplainabilityBaselineConfig({String? baseliningJobName, MonitoringConstraintsResource? constraintsResource})
ModelExplainabilityBaselineConfig.fromJson(Map<String, dynamic> json)
factory

Properties

baseliningJobName → String?
The name of the baseline model explainability job.
final
constraintsResource → MonitoringConstraintsResource?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited