ModelPackage class

A versioned model that can be deployed for SageMaker inference.

Constructors

ModelPackage({String? approvalDescription, bool? certifyForMarketplace, UserContext? createdBy, DateTime? creationTime, InferenceSpecification? inferenceSpecification, UserContext? lastModifiedBy, DateTime? lastModifiedTime, MetadataProperties? metadataProperties, ModelApprovalStatus? modelApprovalStatus, ModelMetrics? modelMetrics, String? modelPackageArn, String? modelPackageDescription, String? modelPackageGroupName, String? modelPackageName, ModelPackageStatus? modelPackageStatus, ModelPackageStatusDetails? modelPackageStatusDetails, int? modelPackageVersion, SourceAlgorithmSpecification? sourceAlgorithmSpecification, List<Tag>? tags, ModelPackageValidationSpecification? validationSpecification})
ModelPackage.fromJson(Map<String, dynamic> json)
factory

Properties

approvalDescription → String?
A description provided when the model approval is set.
final
certifyForMarketplace → bool?
Whether the model package is to be certified to be listed on AWS Marketplace. For information about listing model packages on AWS Marketplace, see List Your Algorithm or Model Package on AWS Marketplace.
final
createdBy → UserContext?
final
creationTime → DateTime?
The time that the model package was created.
final
hashCode → int
The hash code for this object.
no setterinherited
inferenceSpecification → InferenceSpecification?
final
lastModifiedBy → UserContext?
final
lastModifiedTime → DateTime?
The last time the model package was modified.
final
metadataProperties → MetadataProperties?
final
modelApprovalStatus → ModelApprovalStatus?
The approval status of the model. This can be one of the following values.
final
modelMetrics → ModelMetrics?
Metrics for the model.
final
modelPackageArn → String?
The Amazon Resource Name (ARN) of the model package.
final
modelPackageDescription → String?
The description of the model package.
final
modelPackageGroupName → String?
The model group to which the model belongs.
final
modelPackageName → String?
The name of the model.
final
modelPackageStatus → ModelPackageStatus?
The status of the model package. This can be one of the following values.
final
modelPackageStatusDetails → ModelPackageStatusDetails?
final
modelPackageVersion → int?
The version number of a versioned model.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceAlgorithmSpecification → SourceAlgorithmSpecification?
final
tags → List<Tag>?
A list of the tags associated with the model package. For more information, see Tagging AWS resources in the AWS General Reference Guide.
final
validationSpecification → ModelPackageValidationSpecification?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited