ModelPackageContainerDefinition class

Describes the Docker container for the model package.

Constructors

ModelPackageContainerDefinition({required String image, String? containerHostname, String? imageDigest, String? modelDataUrl, String? productId})
ModelPackageContainerDefinition.fromJson(Map<String, dynamic> json)
factory

Properties

containerHostname → String?
The DNS host name for the Docker container.
final
hashCode → int
The hash code for this object.
no setterinherited
image → String
The Amazon EC2 Container Registry (Amazon ECR) path where inference code is stored.
final
imageDigest → String?
An MD5 hash of the training algorithm that identifies the Docker image used for training.
final
modelDataUrl → String?
The Amazon S3 path where the model artifacts, which result from model training, are stored. This path must point to a single gzip compressed tar archive (.tar.gz suffix).
final
productId → String?
The AWS Marketplace product ID of the model package.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited