ModelPackageGroup class

A group of versioned models in the model registry.

Constructors

ModelPackageGroup({UserContext? createdBy, DateTime? creationTime, String? modelPackageGroupArn, String? modelPackageGroupDescription, String? modelPackageGroupName, ModelPackageGroupStatus? modelPackageGroupStatus, List<Tag>? tags})
ModelPackageGroup.fromJson(Map<String, dynamic> json)
factory

Properties

createdBy → UserContext?
final
creationTime → DateTime?
The time that the model group was created.
final
hashCode → int
The hash code for this object.
no setterinherited
modelPackageGroupArn → String?
The Amazon Resource Name (ARN) of the model group.
final
modelPackageGroupDescription → String?
The description for the model group.
final
modelPackageGroupName → String?
The name of the model group.
final
modelPackageGroupStatus → ModelPackageGroupStatus?
The status of the model group. This can be one of the following values.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<Tag>?
A list of the tags associated with the model group. For more information, see Tagging AWS resources in the AWS General Reference Guide.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited