ModelPackageGroupSummary class

Summary information about a model group.

Constructors

ModelPackageGroupSummary({required DateTime creationTime, required String modelPackageGroupArn, required String modelPackageGroupName, required ModelPackageGroupStatus modelPackageGroupStatus, String? modelPackageGroupDescription})
ModelPackageGroupSummary.fromJson(Map<String, dynamic> json)
factory

Properties

creationTime → DateTime
The time that the model group was created.
final
hashCode → int
The hash code for this object.
no setterinherited
modelPackageGroupArn → String
The Amazon Resource Name (ARN) of the model group.
final
modelPackageGroupDescription → String?
A description of the model group.
final
modelPackageGroupName → String
The name of the model group.
final
modelPackageGroupStatus → ModelPackageGroupStatus
The status of the model group.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited