ModelPackageStatusItem class

Represents the overall status of a model package.

Constructors

ModelPackageStatusItem({required String name, required DetailedModelPackageStatus status, String? failureReason})
ModelPackageStatusItem.fromJson(Map<String, dynamic> json)
factory

Properties

failureReason → String?
if the overall status is Failed, the reason for the failure.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the model package for which the overall status is being reported.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → DetailedModelPackageStatus
The current status.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited