ModelPackageSummary class

Provides summary information about a model package.

Constructors

ModelPackageSummary({required DateTime creationTime, required String modelPackageArn, required String modelPackageName, required ModelPackageStatus modelPackageStatus, ModelApprovalStatus? modelApprovalStatus, String? modelPackageDescription, String? modelPackageGroupName, int? modelPackageVersion})
ModelPackageSummary.fromJson(Map<String, dynamic> json)
factory

Properties

creationTime → DateTime
A timestamp that shows when the model package was created.
final
hashCode → int
The hash code for this object.
no setterinherited
modelApprovalStatus → ModelApprovalStatus?
The approval status of the model. This can be one of the following values.
final
modelPackageArn → String
The Amazon Resource Name (ARN) of the model package.
final
modelPackageDescription → String?
A brief description of the model package.
final
modelPackageGroupName → String?
If the model package is a versioned model, the model group that the versioned model belongs to.
final
modelPackageName → String
The name of the model package.
final
modelPackageStatus → ModelPackageStatus
The overall status of the model package.
final
modelPackageVersion → int?
If the model package is a versioned model, the version of the model.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited