ModelPackageValidationSpecification class

Specifies batch transform jobs that Amazon SageMaker runs to validate your model package.

Constructors

ModelPackageValidationSpecification({required List<ModelPackageValidationProfile> validationProfiles, required String validationRole})
ModelPackageValidationSpecification.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validationProfiles → List<ModelPackageValidationProfile>
An array of ModelPackageValidationProfile objects, each of which specifies a batch transform job that Amazon SageMaker runs to validate your model package.
final
validationRole → String
The IAM roles to be used for the validation of the model package.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited