ModelQuality class

Model quality statistics and constraints.

Constructors

ModelQuality({MetricsSource? constraints, MetricsSource? statistics})
ModelQuality.fromJson(Map<String, dynamic> json)
factory

Properties

constraints → MetricsSource?
Model quality constraints.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statistics → MetricsSource?
Model quality statistics.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited