MonitoringJobDefinition class

Defines the monitoring job.

Constructors

MonitoringJobDefinition({required MonitoringAppSpecification monitoringAppSpecification, required List<MonitoringInput> monitoringInputs, required MonitoringOutputConfig monitoringOutputConfig, required MonitoringResources monitoringResources, required String roleArn, MonitoringBaselineConfig? baselineConfig, Map<String, String>? environment, NetworkConfig? networkConfig, MonitoringStoppingCondition? stoppingCondition})
MonitoringJobDefinition.fromJson(Map<String, dynamic> json)
factory

Properties

baselineConfig → MonitoringBaselineConfig?
Baseline configuration used to validate that the data conforms to the specified constraints and statistics
final
environment → Map<String, String>?
Sets the environment variables in the Docker container.
final
hashCode → int
The hash code for this object.
no setterinherited
monitoringAppSpecification → MonitoringAppSpecification
Configures the monitoring job to run a specified Docker container image.
final
monitoringInputs → List<MonitoringInput>
The array of inputs for the monitoring job. Currently we support monitoring an Amazon SageMaker Endpoint.
final
monitoringOutputConfig → MonitoringOutputConfig
The array of outputs from the monitoring job to be uploaded to Amazon Simple Storage Service (Amazon S3).
final
monitoringResources → MonitoringResources
Identifies the resources, ML compute instances, and ML storage volumes to deploy for a monitoring job. In distributed processing, you specify more than one instance.
final
networkConfig → NetworkConfig?
Specifies networking options for an monitoring job.
final
roleArn → String
The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to perform tasks on your behalf.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stoppingCondition → MonitoringStoppingCondition?
Specifies a time limit for how long the monitoring job is allowed to run.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited