MonitoringJobDefinitionSummary class

Summary information about a monitoring job.

Constructors

MonitoringJobDefinitionSummary({required DateTime creationTime, required String endpointName, required String monitoringJobDefinitionArn, required String monitoringJobDefinitionName})
MonitoringJobDefinitionSummary.fromJson(Map<String, dynamic> json)
factory

Properties

creationTime → DateTime
The time that the monitoring job was created.
final
endpointName → String
The name of the endpoint that the job monitors.
final
hashCode → int
The hash code for this object.
no setterinherited
monitoringJobDefinitionArn → String
The Amazon Resource Name (ARN) of the monitoring job.
final
monitoringJobDefinitionName → String
The name of the monitoring job.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited