MonitoringOutput class

The output object for a monitoring job.

Constructors

MonitoringOutput({required MonitoringS3Output s3Output})
MonitoringOutput.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3Output → MonitoringS3Output
The Amazon S3 storage location where the results of a monitoring job are saved.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited