MonitoringOutputConfig class

The output configuration for monitoring jobs.

Constructors

MonitoringOutputConfig({required List<MonitoringOutput> monitoringOutputs, String? kmsKeyId})
MonitoringOutputConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
kmsKeyId → String?
The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt the model artifacts at rest using Amazon S3 server-side encryption.
final
monitoringOutputs → List<MonitoringOutput>
Monitoring outputs for monitoring jobs. This is where the output of the periodic monitoring jobs is uploaded.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited