MonitoringS3Output class

Information about where and how you want to store the results of a monitoring job.

Constructors

MonitoringS3Output({required String localPath, required String s3Uri, ProcessingS3UploadMode? s3UploadMode})
MonitoringS3Output.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
localPath → String
The local path to the Amazon S3 storage location where Amazon SageMaker saves the results of a monitoring job. LocalPath is an absolute path for the output data.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3UploadMode → ProcessingS3UploadMode?
Whether to upload the results of the monitoring job continuously or after the job completes.
final
s3Uri → String
A URI that identifies the Amazon S3 storage location where Amazon SageMaker saves the results of a monitoring job.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited