MonitoringSchedule class

A schedule for a model monitoring job. For information about model monitor, see Amazon SageMaker Model Monitor.

Constructors

MonitoringSchedule({DateTime? creationTime, String? endpointName, String? failureReason, DateTime? lastModifiedTime, MonitoringExecutionSummary? lastMonitoringExecutionSummary, String? monitoringScheduleArn, MonitoringScheduleConfig? monitoringScheduleConfig, String? monitoringScheduleName, ScheduleStatus? monitoringScheduleStatus, MonitoringType? monitoringType, List<Tag>? tags})
MonitoringSchedule.fromJson(Map<String, dynamic> json)
factory

Properties

creationTime → DateTime?
The time that the monitoring schedule was created.
final
endpointName → String?
The endpoint that hosts the model being monitored.
final
failureReason → String?
If the monitoring schedule failed, the reason it failed.
final
hashCode → int
The hash code for this object.
no setterinherited
lastModifiedTime → DateTime?
The last time the monitoring schedule was changed.
final
lastMonitoringExecutionSummary → MonitoringExecutionSummary?
final
monitoringScheduleArn → String?
The Amazon Resource Name (ARN) of the monitoring schedule.
final
monitoringScheduleConfig → MonitoringScheduleConfig?
final
monitoringScheduleName → String?
The name of the monitoring schedule.
final
monitoringScheduleStatus → ScheduleStatus?
The status of the monitoring schedule. This can be one of the following values.
final
monitoringType → MonitoringType?
The type of the monitoring job definition to schedule.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<Tag>?
A list of the tags associated with the monitoring schedlue. For more information, see Tagging AWS resources in the AWS General Reference Guide.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited