NetworkConfig class

Networking options for a job, such as network traffic encryption between containers, whether to allow inbound and outbound network calls to and from containers, and the VPC subnets and security groups to use for VPC-enabled jobs.

Constructors

NetworkConfig({bool? enableInterContainerTrafficEncryption, bool? enableNetworkIsolation, VpcConfig? vpcConfig})
NetworkConfig.fromJson(Map<String, dynamic> json)
factory

Properties

enableInterContainerTrafficEncryption → bool?
Whether to encrypt all communications between distributed processing jobs. Choose True to encrypt communications. Encryption provides greater security for distributed processing jobs, but the processing might take longer.
final
enableNetworkIsolation → bool?
Whether to allow inbound and outbound network calls to and from the containers used for the processing job.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vpcConfig → VpcConfig?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited