NotebookInstanceLifecycleConfigSummary class

Provides a summary of a notebook instance lifecycle configuration.

Constructors

NotebookInstanceLifecycleConfigSummary({required String notebookInstanceLifecycleConfigArn, required String notebookInstanceLifecycleConfigName, DateTime? creationTime, DateTime? lastModifiedTime})
NotebookInstanceLifecycleConfigSummary.fromJson(Map<String, dynamic> json)
factory

Properties

creationTime → DateTime?
A timestamp that tells when the lifecycle configuration was created.
final
hashCode → int
The hash code for this object.
no setterinherited
lastModifiedTime → DateTime?
A timestamp that tells when the lifecycle configuration was last modified.
final
notebookInstanceLifecycleConfigArn → String
The Amazon Resource Name (ARN) of the lifecycle configuration.
final
notebookInstanceLifecycleConfigName → String
The name of the lifecycle configuration.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited