NotificationConfiguration class

Configures SNS notifications of available or expiring work items for work teams.

Constructors

NotificationConfiguration({String? notificationTopicArn})
NotificationConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
notificationTopicArn → String?
The ARN for the SNS topic to which notifications should be published.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited