OfflineStoreConfig class

The configuration of an OfflineStore.

Provide an OfflineStoreConfig in a request to CreateFeatureGroup to create an OfflineStore.

To encrypt an OfflineStore using at rest data encryption, specify AWS Key Management Service (KMS) key ID, or KMSKeyId, in S3StorageConfig.

Constructors

OfflineStoreConfig({required S3StorageConfig s3StorageConfig, DataCatalogConfig? dataCatalogConfig, bool? disableGlueTableCreation})
OfflineStoreConfig.fromJson(Map<String, dynamic> json)
factory

Properties

dataCatalogConfig → DataCatalogConfig?
The meta data of the Glue table that is autogenerated when an OfflineStore is created.
final
disableGlueTableCreation → bool?
Set to True to disable the automatic creation of an AWS Glue table when configuring an OfflineStore.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3StorageConfig → S3StorageConfig
The Amazon Simple Storage (Amazon S3) location of OfflineStore.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited