OfflineStoreStatus class

The status of OfflineStore.

Constructors

OfflineStoreStatus({required OfflineStoreStatusValue status, String? blockedReason})
OfflineStoreStatus.fromJson(Map<String, dynamic> json)
factory

Properties

blockedReason → String?
The justification for why the OfflineStoreStatus is Blocked (if applicable).
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → OfflineStoreStatusValue
An OfflineStore status.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited