OidcConfigForResponse class

Your OIDC IdP workforce configuration.

Constructors

OidcConfigForResponse({String? authorizationEndpoint, String? clientId, String? issuer, String? jwksUri, String? logoutEndpoint, String? tokenEndpoint, String? userInfoEndpoint})
OidcConfigForResponse.fromJson(Map<String, dynamic> json)
factory

Properties

authorizationEndpoint → String?
The OIDC IdP authorization endpoint used to configure your private workforce.
final
clientId → String?
The OIDC IdP client ID used to configure your private workforce.
final
hashCode → int
The hash code for this object.
no setterinherited
issuer → String?
The OIDC IdP issuer used to configure your private workforce.
final
jwksUri → String?
The OIDC IdP JSON Web Key Set (Jwks) URI used to configure your private workforce.
final
logoutEndpoint → String?
The OIDC IdP logout endpoint used to configure your private workforce.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokenEndpoint → String?
The OIDC IdP token endpoint used to configure your private workforce.
final
userInfoEndpoint → String?
The OIDC IdP user information endpoint used to configure your private workforce.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited