Parameter class

Assigns a value to a named Pipeline parameter.

Constructors

Parameter({required String name, required String value})
Parameter.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the parameter to assign a value to. This parameter name must match a named parameter in the pipeline definition.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
The literal value for the parameter.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited