ParameterRange class

Defines the possible values for categorical, continuous, and integer hyperparameters to be used by an algorithm.

Constructors

ParameterRange({CategoricalParameterRangeSpecification? categoricalParameterRangeSpecification, ContinuousParameterRangeSpecification? continuousParameterRangeSpecification, IntegerParameterRangeSpecification? integerParameterRangeSpecification})
ParameterRange.fromJson(Map<String, dynamic> json)
factory

Properties

categoricalParameterRangeSpecification → CategoricalParameterRangeSpecification?
A CategoricalParameterRangeSpecification object that defines the possible values for a categorical hyperparameter.
final
continuousParameterRangeSpecification → ContinuousParameterRangeSpecification?
A ContinuousParameterRangeSpecification object that defines the possible values for a continuous hyperparameter.
final
hashCode → int
The hash code for this object.
no setterinherited
integerParameterRangeSpecification → IntegerParameterRangeSpecification?
A IntegerParameterRangeSpecification object that defines the possible values for an integer hyperparameter.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited