ParentHyperParameterTuningJob class

A previously completed or stopped hyperparameter tuning job to be used as a starting point for a new hyperparameter tuning job.

Constructors

ParentHyperParameterTuningJob({String? hyperParameterTuningJobName})
ParentHyperParameterTuningJob.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
hyperParameterTuningJobName → String?
The name of the hyperparameter tuning job to be used as a starting point for a new hyperparameter tuning job.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited