PipelineExecutionStepMetadata class

Metadata for a step execution.

Properties

condition → ConditionStepMetadata?
If this is a Condition step metadata object, details on the condition.
final
hashCode → int
The hash code for this object.
no setterinherited
model → ModelStepMetadata?
Metadata for the Model step.
final
processingJob → ProcessingJobStepMetadata?
The Amazon Resource Name (ARN) of the processing job that was run by this step execution.
final
registerModel → RegisterModelStepMetadata?
Metadata for the RegisterModel step.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trainingJob → TrainingJobStepMetadata?
The Amazon Resource Name (ARN) of the training job that was run by this step execution.
final
transformJob → TransformJobStepMetadata?
The Amazon Resource Name (ARN) of the transform job that was run by this step execution.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited