ProcessingInput class

The inputs for a processing job. The processing input must specify exactly one of either S3Input or DatasetDefinition types.

Constructors

ProcessingInput({required String inputName, bool? appManaged, DatasetDefinition? datasetDefinition, ProcessingS3Input? s3Input})
ProcessingInput.fromJson(Map<String, dynamic> json)
factory

Properties

appManaged → bool?
When True, input operations such as data download are managed natively by the processing job application. When False (default), input operations are managed by Amazon SageMaker.
final
datasetDefinition → DatasetDefinition?
Configuration for a Dataset Definition input.
final
hashCode → int
The hash code for this object.
no setterinherited
inputName → String
The name of the inputs for the processing job.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3Input → ProcessingS3Input?
Configuration for processing job inputs in Amazon S3.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited