ProcessingJob class

An Amazon SageMaker processing job that is used to analyze data and evaluate models. For more information, see Process Data and Evaluate Models.

Constructors

ProcessingJob({AppSpecification? appSpecification, String? autoMLJobArn, DateTime? creationTime, Map<String, String>? environment, String? exitMessage, ExperimentConfig? experimentConfig, String? failureReason, DateTime? lastModifiedTime, String? monitoringScheduleArn, NetworkConfig? networkConfig, DateTime? processingEndTime, List<ProcessingInput>? processingInputs, String? processingJobArn, String? processingJobName, ProcessingJobStatus? processingJobStatus, ProcessingOutputConfig? processingOutputConfig, ProcessingResources? processingResources, DateTime? processingStartTime, String? roleArn, ProcessingStoppingCondition? stoppingCondition, List<Tag>? tags, String? trainingJobArn})
ProcessingJob.fromJson(Map<String, dynamic> json)
factory

Properties

appSpecification → AppSpecification?
final
autoMLJobArn → String?
The Amazon Resource Name (ARN) of the AutoML job associated with this processing job.
final
creationTime → DateTime?
The time the processing job was created.
final
environment → Map<String, String>?
Sets the environment variables in the Docker container.
final
exitMessage → String?
A string, up to one KB in size, that contains metadata from the processing container when the processing job exits.
final
experimentConfig → ExperimentConfig?
final
failureReason → String?
A string, up to one KB in size, that contains the reason a processing job failed, if it failed.
final
hashCode → int
The hash code for this object.
no setterinherited
lastModifiedTime → DateTime?
The time the processing job was last modified.
final
monitoringScheduleArn → String?
The ARN of a monitoring schedule for an endpoint associated with this processing job.
final
networkConfig → NetworkConfig?
final
processingEndTime → DateTime?
The time that the processing job ended.
final
processingInputs → List<ProcessingInput>?
List of input configurations for the processing job.
final
processingJobArn → String?
The ARN of the processing job.
final
processingJobName → String?
The name of the processing job.
final
processingJobStatus → ProcessingJobStatus?
The status of the processing job.
final
processingOutputConfig → ProcessingOutputConfig?
final
processingResources → ProcessingResources?
final
processingStartTime → DateTime?
The time that the processing job started.
final
roleArn → String?
The ARN of the role used to create the processing job.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stoppingCondition → ProcessingStoppingCondition?
final
tags → List<Tag>?
An array of key-value pairs. For more information, see Using Cost Allocation Tags in the AWS Billing and Cost Management User Guide.
final
trainingJobArn → String?
The ARN of the training job associated with this processing job.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited