ProcessingJobSummary class

Summary of information about a processing job.

Constructors

ProcessingJobSummary({required DateTime creationTime, required String processingJobArn, required String processingJobName, required ProcessingJobStatus processingJobStatus, String? exitMessage, String? failureReason, DateTime? lastModifiedTime, DateTime? processingEndTime})
ProcessingJobSummary.fromJson(Map<String, dynamic> json)
factory

Properties

creationTime → DateTime
The time at which the processing job was created.
final
exitMessage → String?
An optional string, up to one KB in size, that contains metadata from the processing container when the processing job exits.
final
failureReason → String?
A string, up to one KB in size, that contains the reason a processing job failed, if it failed.
final
hashCode → int
The hash code for this object.
no setterinherited
lastModifiedTime → DateTime?
A timestamp that indicates the last time the processing job was modified.
final
processingEndTime → DateTime?
The time at which the processing job completed.
final
processingJobArn → String
The Amazon Resource Name (ARN) of the processing job..
final
processingJobName → String
The name of the processing job.
final
processingJobStatus → ProcessingJobStatus
The status of the processing job.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited