ProcessingOutput class

Describes the results of a processing job. The processing output must specify exactly one of either S3Output or FeatureStoreOutput types.

Constructors

ProcessingOutput({required String outputName, bool? appManaged, ProcessingFeatureStoreOutput? featureStoreOutput, ProcessingS3Output? s3Output})
ProcessingOutput.fromJson(Map<String, dynamic> json)
factory

Properties

appManaged → bool?
When True, output operations such as data upload are managed natively by the processing job application. When False (default), output operations are managed by Amazon SageMaker.
final
featureStoreOutput → ProcessingFeatureStoreOutput?
Configuration for processing job outputs in Amazon SageMaker Feature Store. This processing output type is only supported when AppManaged is specified.
final
hashCode → int
The hash code for this object.
no setterinherited
outputName → String
The name for the processing job output.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3Output → ProcessingS3Output?
Configuration for processing job outputs in Amazon S3.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited