ProductionVariantSummary class

Describes weight and capacities for a production variant associated with an endpoint. If you sent a request to the UpdateEndpointWeightsAndCapacities API and the endpoint status is Updating, you get different desired and current values.

Constructors

ProductionVariantSummary({required String variantName, int? currentInstanceCount, double? currentWeight, List<DeployedImage>? deployedImages, int? desiredInstanceCount, double? desiredWeight})
ProductionVariantSummary.fromJson(Map<String, dynamic> json)
factory

Properties

currentInstanceCount → int?
The number of instances associated with the variant.
final
currentWeight → double?
The weight associated with the variant.
final
deployedImages → List<DeployedImage>?
An array of DeployedImage objects that specify the Amazon EC2 Container Registry paths of the inference images deployed on instances of this ProductionVariant.
final
desiredInstanceCount → int?
The number of instances requested in the UpdateEndpointWeightsAndCapacities request.
final
desiredWeight → double?
The requested weight, as specified in the UpdateEndpointWeightsAndCapacities request.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
variantName → String
The name of the variant.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited