ProfilerRuleConfiguration class

Configuration information for profiling rules.

Constructors

ProfilerRuleConfiguration({required String ruleConfigurationName, required String ruleEvaluatorImage, ProcessingInstanceType? instanceType, String? localPath, Map<String, String>? ruleParameters, String? s3OutputPath, int? volumeSizeInGB})
ProfilerRuleConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
instanceType → ProcessingInstanceType?
The instance type to deploy a Debugger custom rule for profiling a training job.
final
localPath → String?
Path to local storage location for output of rules. Defaults to /opt/ml/processing/output/rule/.
final
ruleConfigurationName → String
The name of the rule configuration. It must be unique relative to other rule configuration names.
final
ruleEvaluatorImage → String
The Amazon Elastic Container (ECR) Image for the managed rule evaluation.
final
ruleParameters → Map<String, String>?
Runtime configuration for rule container.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3OutputPath → String?
Path to Amazon S3 storage location for rules.
final
volumeSizeInGB → int?
The size, in GB, of the ML storage volume attached to the processing instance.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited