ProjectSummary class

Information about a project.

Constructors

ProjectSummary({required DateTime creationTime, required String projectArn, required String projectId, required String projectName, required ProjectStatus projectStatus, String? projectDescription})
ProjectSummary.fromJson(Map<String, dynamic> json)
factory

Properties

creationTime → DateTime
The time that the project was created.
final
hashCode → int
The hash code for this object.
no setterinherited
projectArn → String
The Amazon Resource Name (ARN) of the project.
final
projectDescription → String?
The description of the project.
final
projectId → String
The ID of the project.
final
projectName → String
The name of the project.
final
projectStatus → ProjectStatus
The status of the project.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited