PropertyNameQuery class

Part of the SuggestionQuery type. Specifies a hint for retrieving property names that begin with the specified text.

Constructors

PropertyNameQuery({required String propertyNameHint})

Properties

hashCode → int
The hash code for this object.
no setterinherited
propertyNameHint → String
Text that begins a property's name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited