RedshiftDatasetDefinition class

Configuration for Redshift Dataset Definition input.

Constructors

RedshiftDatasetDefinition({required String clusterId, required String clusterRoleArn, required String database, required String dbUser, required RedshiftResultFormat outputFormat, required String outputS3Uri, required String queryString, String? kmsKeyId, RedshiftResultCompressionType? outputCompression})
RedshiftDatasetDefinition.fromJson(Map<String, dynamic> json)
factory

Properties

clusterId → String
final
clusterRoleArn → String
The IAM role attached to your Redshift cluster that Amazon SageMaker uses to generate datasets.
final
database → String
final
dbUser → String
final
hashCode → int
The hash code for this object.
no setterinherited
kmsKeyId → String?
The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt data from a Redshift execution.
final
outputCompression → RedshiftResultCompressionType?
final
outputFormat → RedshiftResultFormat
final
outputS3Uri → String
The location in Amazon S3 where the Redshift query results are stored.
final
queryString → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited