ResolvedAttributes class

The resolved attributes.

Constructors

ResolvedAttributes({AutoMLJobObjective? autoMLJobObjective, AutoMLJobCompletionCriteria? completionCriteria, ProblemType? problemType})
ResolvedAttributes.fromJson(Map<String, dynamic> json)
factory

Properties

autoMLJobObjective → AutoMLJobObjective?
final
completionCriteria → AutoMLJobCompletionCriteria?
final
hashCode → int
The hash code for this object.
no setterinherited
problemType → ProblemType?
The problem type.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited