ResourceConfig class

Describes the resources, including ML compute instances and ML storage volumes, to use for model training.

Constructors

ResourceConfig({required int instanceCount, required TrainingInstanceType instanceType, required int volumeSizeInGB, String? volumeKmsKeyId})
ResourceConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
instanceCount → int
The number of ML compute instances to use. For distributed training, provide a value greater than 1.
final
instanceType → TrainingInstanceType
The ML compute instance type.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
volumeKmsKeyId → String?
The AWS KMS key that Amazon SageMaker uses to encrypt data on the storage volume attached to the ML compute instance(s) that run the training job.
final
volumeSizeInGB → int
The size of the ML storage volume that you want to provision.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited