ResourceLimits class

Specifies the maximum number of training jobs and parallel training jobs that a hyperparameter tuning job can launch.

Constructors

ResourceLimits({required int maxNumberOfTrainingJobs, required int maxParallelTrainingJobs})
ResourceLimits.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxNumberOfTrainingJobs → int
The maximum number of training jobs that a hyperparameter tuning job can launch.
final
maxParallelTrainingJobs → int
The maximum number of concurrent training jobs that a hyperparameter tuning job can launch.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited