ResourceSpec class

Specifies the ARN's of a SageMaker image and SageMaker image version, and the instance type that the version runs on.

Constructors

ResourceSpec({AppInstanceType? instanceType, String? sageMakerImageArn, String? sageMakerImageVersionArn})
ResourceSpec.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
instanceType → AppInstanceType?
The instance type that the image version runs on.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sageMakerImageArn → String?
The ARN of the SageMaker image that the image version belongs to.
final
sageMakerImageVersionArn → String?
The ARN of the image version created on the instance.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited