S3DataSource class

Describes the S3 data source.

Constructors

S3DataSource({required S3DataType s3DataType, required String s3Uri, List<String>? attributeNames, S3DataDistribution? s3DataDistributionType})
S3DataSource.fromJson(Map<String, dynamic> json)
factory

Properties

attributeNames → List<String>?
A list of one or more attribute names to use that are found in a specified augmented manifest file.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3DataDistributionType → S3DataDistribution?
If you want Amazon SageMaker to replicate the entire dataset on each ML compute instance that is launched for model training, specify FullyReplicated.
final
s3DataType → S3DataType
If you choose S3Prefix, S3Uri identifies a key name prefix. Amazon SageMaker uses all objects that match the specified key name prefix for model training.
final
s3Uri → String
Depending on the value specified for the S3DataType, identifies either a key name prefix or a manifest. For example:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited