S3StorageConfig class

The Amazon Simple Storage (Amazon S3) location and and security configuration for OfflineStore.

Constructors

S3StorageConfig({required String s3Uri, String? kmsKeyId})
S3StorageConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
kmsKeyId → String?
The AWS Key Management Service (KMS) key ID of the key used to encrypt any objects written into the OfflineStore S3 location.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3Uri → String
The S3 URI, or location in Amazon S3, of OfflineStore.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited