SearchRecord class

A single resource returned as part of the Search API response.

Constructors

SearchRecord({Endpoint? endpoint, Experiment? experiment, FeatureGroup? featureGroup, ModelPackage? modelPackage, ModelPackageGroup? modelPackageGroup, Pipeline? pipeline, PipelineExecution? pipelineExecution, TrainingJob? trainingJob, Trial? trial, TrialComponent? trialComponent})
SearchRecord.fromJson(Map<String, dynamic> json)
factory

Properties

endpoint → Endpoint?
final
experiment → Experiment?
The properties of an experiment.
final
featureGroup → FeatureGroup?
final
hashCode → int
The hash code for this object.
no setterinherited
modelPackage → ModelPackage?
final
modelPackageGroup → ModelPackageGroup?
final
pipeline → Pipeline?
final
pipelineExecution → PipelineExecution?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trainingJob → TrainingJob?
The properties of a training job.
final
trial → Trial?
The properties of a trial.
final
trialComponent → TrialComponent?
The properties of a trial component.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited