SourceAlgorithmSpecification class

A list of algorithms that were used to create a model package.

Constructors

SourceAlgorithmSpecification({required List<SourceAlgorithm> sourceAlgorithms})
SourceAlgorithmSpecification.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceAlgorithms → List<SourceAlgorithm>
A list of the algorithms that were used to create a model package.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited