SubscribedWorkteam class

Describes a work team of a vendor that does the a labelling job.

Constructors

SubscribedWorkteam({required String workteamArn, String? listingId, String? marketplaceDescription, String? marketplaceTitle, String? sellerName})
SubscribedWorkteam.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
listingId → String?
Marketplace product listing ID.
final
marketplaceDescription → String?
The description of the vendor from the Amazon Marketplace.
final
marketplaceTitle → String?
The title of the service provided by the vendor in the Amazon Marketplace.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sellerName → String?
The name of the vendor in the Amazon Marketplace.
final
workteamArn → String
The Amazon Resource Name (ARN) of the vendor that you have subscribed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited