TrafficRoutingConfig class

Currently, the TrafficRoutingConfig API is not supported.

Constructors

TrafficRoutingConfig({required TrafficRoutingConfigType type, required int waitIntervalInSeconds, CapacitySize? canarySize})
TrafficRoutingConfig.fromJson(Map<String, dynamic> json)
factory

Properties

canarySize → CapacitySize?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → TrafficRoutingConfigType
final
waitIntervalInSeconds → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited