TrainingJobDefinition class

Defines the input needed to run a training job using the algorithm.

Constructors

TrainingJobDefinition({required List<Channel> inputDataConfig, required OutputDataConfig outputDataConfig, required ResourceConfig resourceConfig, required StoppingCondition stoppingCondition, required TrainingInputMode trainingInputMode, Map<String, String>? hyperParameters})
TrainingJobDefinition.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
hyperParameters → Map<String, String>?
The hyperparameters used for the training job.
final
inputDataConfig → List<Channel>
An array of Channel objects, each of which specifies an input source.
final
outputDataConfig → OutputDataConfig
the path to the S3 bucket where you want to store model artifacts. Amazon SageMaker creates subfolders for the artifacts.
final
resourceConfig → ResourceConfig
The resources, including the ML compute instances and ML storage volumes, to use for model training.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stoppingCondition → StoppingCondition
Specifies a limit to how long a model training job can run. When the job reaches the time limit, Amazon SageMaker ends the training job. Use this API to cap model training costs.
final
trainingInputMode → TrainingInputMode
The input mode used by the algorithm for the training job. For the input modes that Amazon SageMaker algorithms support, see Algorithms.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited