TrainingJobStatusCounters class

The numbers of training jobs launched by a hyperparameter tuning job, categorized by status.

Constructors

TrainingJobStatusCounters({int? completed, int? inProgress, int? nonRetryableError, int? retryableError, int? stopped})
TrainingJobStatusCounters.fromJson(Map<String, dynamic> json)
factory

Properties

completed → int?
The number of completed training jobs launched by the hyperparameter tuning job.
final
hashCode → int
The hash code for this object.
no setterinherited
inProgress → int?
The number of in-progress training jobs launched by a hyperparameter tuning job.
final
nonRetryableError → int?
The number of training jobs that failed and can't be retried. A failed training job can't be retried if it failed because a client error occurred.
final
retryableError → int?
The number of training jobs that failed, but can be retried. A failed training job can be retried only if it failed because an internal service error occurred.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stopped → int?
The number of training jobs launched by a hyperparameter tuning job that were manually stopped.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited