TrainingSpecification class

Defines how the algorithm is used for a training job.

Constructors

TrainingSpecification({required List<TrainingInstanceType> supportedTrainingInstanceTypes, required List<ChannelSpecification> trainingChannels, required String trainingImage, List<MetricDefinition>? metricDefinitions, List<HyperParameterSpecification>? supportedHyperParameters, List<HyperParameterTuningJobObjective>? supportedTuningJobObjectiveMetrics, bool? supportsDistributedTraining, String? trainingImageDigest})
TrainingSpecification.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
metricDefinitions → List<MetricDefinition>?
A list of MetricDefinition objects, which are used for parsing metrics generated by the algorithm.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedHyperParameters → List<HyperParameterSpecification>?
A list of the HyperParameterSpecification objects, that define the supported hyperparameters. This is required if the algorithm supports automatic model tuning.>
final
supportedTrainingInstanceTypes → List<TrainingInstanceType>
A list of the instance types that this algorithm can use for training.
final
supportedTuningJobObjectiveMetrics → List<HyperParameterTuningJobObjective>?
A list of the metrics that the algorithm emits that can be used as the objective metric in a hyperparameter tuning job.
final
supportsDistributedTraining → bool?
Indicates whether the algorithm supports distributed training. If set to false, buyers can't request more than one instance during training.
final
trainingChannels → List<ChannelSpecification>
A list of ChannelSpecification objects, which specify the input sources to be used by the algorithm.
final
trainingImage → String
The Amazon ECR registry path of the Docker image that contains the training algorithm.
final
trainingImageDigest → String?
An MD5 hash of the training algorithm that identifies the Docker image used for training.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited