TransformJob class

A batch transform job. For information about SageMaker batch transform, see Use Batch Transform.

Constructors

TransformJob({String? autoMLJobArn, BatchStrategy? batchStrategy, DateTime? creationTime, DataProcessing? dataProcessing, Map<String, String>? environment, ExperimentConfig? experimentConfig, String? failureReason, String? labelingJobArn, int? maxConcurrentTransforms, int? maxPayloadInMB, ModelClientConfig? modelClientConfig, String? modelName, List<Tag>? tags, DateTime? transformEndTime, TransformInput? transformInput, String? transformJobArn, String? transformJobName, TransformJobStatus? transformJobStatus, TransformOutput? transformOutput, TransformResources? transformResources, DateTime? transformStartTime})
TransformJob.fromJson(Map<String, dynamic> json)
factory

Properties

autoMLJobArn → String?
The Amazon Resource Name (ARN) of the AutoML job that created the transform job.
final
batchStrategy → BatchStrategy?
Specifies the number of records to include in a mini-batch for an HTTP inference request. A record is a single unit of input data that inference can be made on. For example, a single line in a CSV file is a record.
final
creationTime → DateTime?
A timestamp that shows when the transform Job was created.
final
dataProcessing → DataProcessing?
final
environment → Map<String, String>?
The environment variables to set in the Docker container. We support up to 16 key and values entries in the map.
final
experimentConfig → ExperimentConfig?
final
failureReason → String?
If the transform job failed, the reason it failed.
final
hashCode → int
The hash code for this object.
no setterinherited
labelingJobArn → String?
The Amazon Resource Name (ARN) of the labeling job that created the transform job.
final
maxConcurrentTransforms → int?
The maximum number of parallel requests that can be sent to each instance in a transform job. If MaxConcurrentTransforms is set to 0 or left unset, SageMaker checks the optional execution-parameters to determine the settings for your chosen algorithm. If the execution-parameters endpoint is not enabled, the default value is 1. For built-in algorithms, you don't need to set a value for MaxConcurrentTransforms.
final
maxPayloadInMB → int?
The maximum allowed size of the payload, in MB. A payload is the data portion of a record (without metadata). The value in MaxPayloadInMB must be greater than, or equal to, the size of a single record. To estimate the size of a record in MB, divide the size of your dataset by the number of records. To ensure that the records fit within the maximum payload size, we recommend using a slightly larger value. The default value is 6 MB. For cases where the payload might be arbitrarily large and is transmitted using HTTP chunked encoding, set the value to 0. This feature works only in supported algorithms. Currently, SageMaker built-in algorithms do not support HTTP chunked encoding.
final
modelClientConfig → ModelClientConfig?
final
modelName → String?
The name of the model associated with the transform job.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<Tag>?
A list of tags associated with the transform job.
final
transformEndTime → DateTime?
Indicates when the transform job has been completed, or has stopped or failed. You are billed for the time interval between this time and the value of TransformStartTime.
final
transformInput → TransformInput?
final
transformJobArn → String?
The Amazon Resource Name (ARN) of the transform job.
final
transformJobName → String?
The name of the transform job.
final
transformJobStatus → TransformJobStatus?
The status of the transform job.
final
transformOutput → TransformOutput?
final
transformResources → TransformResources?
final
transformStartTime → DateTime?
Indicates when the transform job starts on ML instances. You are billed for the time interval between this time and the value of TransformEndTime.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited