TransformJobDefinition class

Defines the input needed to run a transform job using the inference specification specified in the algorithm.

Constructors

TransformJobDefinition({required TransformInput transformInput, required TransformOutput transformOutput, required TransformResources transformResources, BatchStrategy? batchStrategy, Map<String, String>? environment, int? maxConcurrentTransforms, int? maxPayloadInMB})
TransformJobDefinition.fromJson(Map<String, dynamic> json)
factory

Properties

batchStrategy → BatchStrategy?
A string that determines the number of records included in a single mini-batch.
final
environment → Map<String, String>?
The environment variables to set in the Docker container. We support up to 16 key and values entries in the map.
final
hashCode → int
The hash code for this object.
no setterinherited
maxConcurrentTransforms → int?
The maximum number of parallel requests that can be sent to each instance in a transform job. The default value is 1.
final
maxPayloadInMB → int?
The maximum payload size allowed, in MB. A payload is the data portion of a record (without metadata).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transformInput → TransformInput
A description of the input source and the way the transform job consumes it.
final
transformOutput → TransformOutput
Identifies the Amazon S3 location where you want Amazon SageMaker to save the results from the transform job.
final
transformResources → TransformResources
Identifies the ML compute instances for the transform job.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited