TransformOutput class

Describes the results of a transform job.

Constructors

TransformOutput({required String s3OutputPath, String? accept, AssemblyType? assembleWith, String? kmsKeyId})
TransformOutput.fromJson(Map<String, dynamic> json)
factory

Properties

accept → String?
The MIME type used to specify the output data. Amazon SageMaker uses the MIME type with each http call to transfer data from the transform job.
final
assembleWith → AssemblyType?
Defines how to assemble the results of the transform job as a single S3 object. Choose a format that is most convenient to you. To concatenate the results in binary format, specify None. To add a newline character at the end of every transformed record, specify Line.
final
hashCode → int
The hash code for this object.
no setterinherited
kmsKeyId → String?
The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt the model artifacts at rest using Amazon S3 server-side encryption. The KmsKeyId can be any of the following formats:
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3OutputPath → String
The Amazon S3 path where you want Amazon SageMaker to store the results of the transform job. For example, s3://bucket-name/key-name-prefix.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited