TransformS3DataSource class

Describes the S3 data source.

Constructors

TransformS3DataSource({required S3DataType s3DataType, required String s3Uri})
TransformS3DataSource.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3DataType → S3DataType
If you choose S3Prefix, S3Uri identifies a key name prefix. Amazon SageMaker uses all objects with the specified key name prefix for batch transform.
final
s3Uri → String
Depending on the value specified for the S3DataType, identifies either a key name prefix or a manifest. For example:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited