TrialComponent class

The properties of a trial component as returned by the Search API.

Constructors

TrialComponent({UserContext? createdBy, DateTime? creationTime, String? displayName, DateTime? endTime, Map<String, TrialComponentArtifact>? inputArtifacts, UserContext? lastModifiedBy, DateTime? lastModifiedTime, MetadataProperties? metadataProperties, List<TrialComponentMetricSummary>? metrics, Map<String, TrialComponentArtifact>? outputArtifacts, Map<String, TrialComponentParameterValue>? parameters, List<Parent>? parents, TrialComponentSource? source, TrialComponentSourceDetail? sourceDetail, DateTime? startTime, TrialComponentStatus? status, List<Tag>? tags, String? trialComponentArn, String? trialComponentName})
TrialComponent.fromJson(Map<String, dynamic> json)
factory

Properties

createdBy → UserContext?
final
creationTime → DateTime?
When the component was created.
final
displayName → String?
The name of the component as displayed. If DisplayName isn't specified, TrialComponentName is displayed.
final
endTime → DateTime?
When the component ended.
final
hashCode → int
The hash code for this object.
no setterinherited
inputArtifacts → Map<String, TrialComponentArtifact>?
The input artifacts of the component.
final
lastModifiedBy → UserContext?
final
lastModifiedTime → DateTime?
When the component was last modified.
final
metadataProperties → MetadataProperties?
final
metrics → List<TrialComponentMetricSummary>?
The metrics for the component.
final
outputArtifacts → Map<String, TrialComponentArtifact>?
The output artifacts of the component.
final
parameters → Map<String, TrialComponentParameterValue>?
The hyperparameters of the component.
final
parents → List<Parent>?
An array of the parents of the component. A parent is a trial the component is associated with and the experiment the trial is part of. A component might not have any parents.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → TrialComponentSource?
The Amazon Resource Name (ARN) and job type of the source of the component.
final
sourceDetail → TrialComponentSourceDetail?
Details of the source of the component.
final
startTime → DateTime?
When the component started.
final
status → TrialComponentStatus?
final
tags → List<Tag>?
The list of tags that are associated with the component. You can use Search API to search on the tags.
final
trialComponentArn → String?
The Amazon Resource Name (ARN) of the trial component.
final
trialComponentName → String?
The name of the trial component.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited