TrialComponentSimpleSummary class

A short summary of a trial component.

Constructors

TrialComponentSimpleSummary({UserContext? createdBy, DateTime? creationTime, String? trialComponentArn, String? trialComponentName, TrialComponentSource? trialComponentSource})
TrialComponentSimpleSummary.fromJson(Map<String, dynamic> json)
factory

Properties

createdBy → UserContext?
final
creationTime → DateTime?
When the component was created.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trialComponentArn → String?
The Amazon Resource Name (ARN) of the trial component.
final
trialComponentName → String?
The name of the trial component.
final
trialComponentSource → TrialComponentSource?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited