UserContext class

Information about the user who created or modified an experiment, trial, or trial component.

Constructors

UserContext({String? domainId, String? userProfileArn, String? userProfileName})
UserContext.fromJson(Map<String, dynamic> json)
factory

Properties

domainId → String?
The domain associated with the user.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userProfileArn → String?
The Amazon Resource Name (ARN) of the user's profile.
final
userProfileName → String?
The name of the user's profile.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited