UserSettings class

A collection of settings.

Constructors

UserSettings({String? executionRole, JupyterServerAppSettings? jupyterServerAppSettings, KernelGatewayAppSettings? kernelGatewayAppSettings, List<String>? securityGroups, SharingSettings? sharingSettings, TensorBoardAppSettings? tensorBoardAppSettings})
UserSettings.fromJson(Map<String, dynamic> json)
factory

Properties

executionRole → String?
The execution role for the user.
final
hashCode → int
The hash code for this object.
no setterinherited
jupyterServerAppSettings → JupyterServerAppSettings?
The Jupyter server's app settings.
final
kernelGatewayAppSettings → KernelGatewayAppSettings?
The kernel gateway app settings.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityGroups → List<String>?
The security groups for the Amazon Virtual Private Cloud (VPC) that Studio uses for communication.
final
sharingSettings → SharingSettings?
The sharing settings.
final
tensorBoardAppSettings → TensorBoardAppSettings?
The TensorBoard app settings.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited