VariantProperty class

Specifies a production variant property type for an Endpoint.

If you are updating an endpoint with the UpdateEndpointInput$RetainAllVariantProperties option set to true, the VariantProperty objects listed in UpdateEndpointInput$ExcludeRetainedVariantProperties override the existing variant properties of the endpoint.

Constructors

VariantProperty({required VariantPropertyType variantPropertyType})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
variantPropertyType → VariantPropertyType
The type of variant property. The supported values are:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited