Workforce class

A single private workforce, which is automatically created when you create your first private work team. You can create one private work force in each AWS Region. By default, any workforce-related API operation used in a specific region will apply to the workforce created in that region. To learn how to create a private workforce, see Create a Private Workforce.

Constructors

Workforce({required String workforceArn, required String workforceName, CognitoConfig? cognitoConfig, DateTime? createDate, DateTime? lastUpdatedDate, OidcConfigForResponse? oidcConfig, SourceIpConfig? sourceIpConfig, String? subDomain})
Workforce.fromJson(Map<String, dynamic> json)
factory

Properties

cognitoConfig → CognitoConfig?
The configuration of an Amazon Cognito workforce. A single Cognito workforce is created using and corresponds to a single Amazon Cognito user pool.
final
createDate → DateTime?
The date that the workforce is created.
final
hashCode → int
The hash code for this object.
no setterinherited
lastUpdatedDate → DateTime?
The most recent date that was used to successfully add one or more IP address ranges (CIDRs) to a private workforce's allow list.
final
oidcConfig → OidcConfigForResponse?
The configuration of an OIDC Identity Provider (IdP) private workforce.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceIpConfig → SourceIpConfig?
A list of one to ten IP address ranges (CIDRs) to be added to the workforce allow list. By default, a workforce isn't restricted to specific IP addresses.
final
subDomain → String?
The subdomain for your OIDC Identity Provider.
final
workforceArn → String
The Amazon Resource Name (ARN) of the private workforce.
final
workforceName → String
The name of the private workforce.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited