Workteam class

Provides details about a labeling work team.

Constructors

Workteam({required String description, required List<MemberDefinition> memberDefinitions, required String workteamArn, required String workteamName, DateTime? createDate, DateTime? lastUpdatedDate, NotificationConfiguration? notificationConfiguration, List<String>? productListingIds, String? subDomain, String? workforceArn})
Workteam.fromJson(Map<String, dynamic> json)
factory

Properties

createDate → DateTime?
The date and time that the work team was created (timestamp).
final
description → String
A description of the work team.
final
hashCode → int
The hash code for this object.
no setterinherited
lastUpdatedDate → DateTime?
The date and time that the work team was last updated (timestamp).
final
memberDefinitions → List<MemberDefinition>
A list of MemberDefinition objects that contains objects that identify the workers that make up the work team.
final
notificationConfiguration → NotificationConfiguration?
Configures SNS notifications of available or expiring work items for work teams.
final
productListingIds → List<String>?
The Amazon Marketplace identifier for a vendor's work team.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subDomain → String?
The URI of the labeling job's user interface. Workers open this URI to start labeling your data objects.
final
workforceArn → String?
The Amazon Resource Name (ARN) of the workforce.
final
workteamArn → String
The Amazon Resource Name (ARN) that identifies the work team.
final
workteamName → String
The name of the work team.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited